using System;
using System.Xml;
using System.IO;
using System.Collections.Generic;
//using Ato.EN.IntegrationServices.Document.DataContracts;
using System.Text.RegularExpressions;
using System.Reflection;
using System.Linq;
using System.Xml.Schema;
using System.Text;
using DataContracts;

namespace Ato.EN.IntegrationServices.CodeGenerationABNREG
{
    /// <summary>
    /// XML Consumer for ABNREGREQUEST
    /// </summary>
    public class ABNREGREQUEST2019XmlConsumer
    {
        const string MissingMandatoryMessage = "A mandatory field has not been completed.";
        const string ContactYourProviderMsg = "The message did not pass XML validation. Please contact your software provider.";
        const string InvalidDataValidation = "A field contains invalid data (such as letters in numeric or date field).";
        private const string ErrorCode1 = "CMN.ATO.GEN.XML01";
        private const string ErrorCode3 = "CMN.ATO.GEN.XML03";
        private const string ErrorCode4 = "CMN.ATO.GEN.XML04";
        private const string ErrorCode6 = "CMN.ATO.GEN.XML06";
        private bool _found = false;
        private int _parentCollectionCount;
        private int _childCollectionCount;
        private bool _isExiting = false;
        private bool _isValidationError = false;
        private string _lastPath = string.Empty;
        private ErrorMessageType _validationError = new ErrorMessageType(ErrorDescriptor.NoError);


        #region Error Messages

        public List<ProcessMessageDocument> ErrorMessages { get; set; }

        public bool HasErrors
        {
            get
            {
                return ErrorMessages != null && ErrorMessages.Count > 0;
            }
        }

        private string GetCurrentLocation()
        {
            StringBuilder location = new StringBuilder();
            string[] paths = _currentXPath.ToArray<string>();
            for (int i = paths.Length - 1; i > -1; i--)
            {
                location.Append(paths[i]);
            }
            return location.ToString();
        }

        private void MissingElementError()
        {
            ProcessMessageDocument processMessage;
            processMessage = new ProcessMessageDocument()
            {
                Code = "CMN.ATO.GEN.XML04",
                Description = MissingMandatoryMessage,
                SeverityAsString = "Error",
                Location = GetCurrentLocation(),
            };
            this.ErrorMessages.Add(processMessage);
        }

        #endregion  Error Messages

        #region Embedded Schema

        private static readonly XmlSchemaSet EmbeddedXmlSchemaSet;
        static ABNREGREQUEST2019XmlConsumer()
        {
            Assembly executingAssembly = Assembly.GetExecutingAssembly();
            string[] manifestResourceNames = executingAssembly.GetManifestResourceNames();
            string resourceName;
            Stream embeddedSchemaStream;
            XmlSchema embeddedXmlSchema;

            if (manifestResourceNames != null)
            {
                resourceName = manifestResourceNames.FirstOrDefault(rn => rn.Contains("ato.abnreg.0004.2019.lodge.01.00.xsd") && rn.EndsWith(".xsd"));
                if (resourceName != null)
                {
                    embeddedSchemaStream = executingAssembly.GetManifestResourceStream(resourceName);
                    embeddedXmlSchema = XmlSchema.Read(embeddedSchemaStream, SchemaCallback);
                    EmbeddedXmlSchemaSet = new XmlSchemaSet();
                    EmbeddedXmlSchemaSet.Add(embeddedXmlSchema);
                    EmbeddedXmlSchemaSet.Compile();
                }
            }
        }

        private static void SchemaCallback(object sender, ValidationEventArgs args)
        {
            if (args.Severity == XmlSeverityType.Error)
                throw new XmlSchemaException(args.Message);
        }

        #endregion  Embedded Schema

        #region Xml Reader Settings

        private static XmlReaderSettings ReaderSettings = new XmlReaderSettings()
        {
            CloseInput = false,
            ConformanceLevel = ConformanceLevel.Fragment,
            IgnoreWhitespace = true,
            IgnoreComments = true,
            IgnoreProcessingInstructions = true,
        };

        private XmlReaderSettings GetValidatingReaderSettings()
        {
            XmlReaderSettings validatingReaderSettings = new XmlReaderSettings()
            {
                CloseInput = false,
                ConformanceLevel = ConformanceLevel.Fragment,
                IgnoreWhitespace = true,
                IgnoreComments = true,
                IgnoreProcessingInstructions = true,
                ValidationType = ValidationType.Schema,
            };
            if (EmbeddedXmlSchemaSet == null)
            {
                throw new XmlSchemaException("Embedded Schema is Null");
            }
            else
            {
                validatingReaderSettings.Schemas.Add(EmbeddedXmlSchemaSet);
                validatingReaderSettings.ValidationEventHandler += new ValidationEventHandler(ValidationCallBack);
            }
            return validatingReaderSettings;
        }

        private static Regex DataTypeFailureExpression = new Regex("'(?<Uniqueid>.*?)' element is invalid.*value '(?<Value>.*?)' is invalid.*datatype '(?<DataType>.*?)'", RegexOptions.IgnoreCase | RegexOptions.Compiled | RegexOptions.Singleline);

        private void ValidationCallBack(object sender, ValidationEventArgs args)
        {
            var msg = args.Message;
            var msgToLower = msg.ToLower();

            ProcessMessageDocument processMessage = null;

            if (msgToLower.Contains("invalid according to its datatype"))
            {
                Match match = DataTypeFailureExpression.Match(args.Message);

                if (match.Success && match.Groups.Count == 4)
                {
                    var inner = args.Exception.InnerException;
                    var hint = (inner != null && !string.IsNullOrEmpty(inner.Message)) ? " Hint: " + inner.Message : string.Empty;
                    processMessage = BuildProcessMessageDocument(InvalidDataValidation, string.Empty, ErrorCode3);

                    string uniqueID = match.Groups["Uniqueid"].Value;
                    string value = match.Groups["Value"].Value;
                    string dataType = match.Groups["DataType"].Value;


                    var longDescription = string.Format(@"The value specified for an item does not match the item type (value = ""{0}"", item type = {1}, uniqueID = {2})", value, dataType, uniqueID);
                    processMessage.LongDescription = longDescription + hint;
                    processMessage.Parameters = new ProcessMessageParameters();
                    processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "uniqueID", Value = uniqueID });
                    processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "value", Value = value });
                    processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "dataType", Value = dataType });
                }
            }
            else if (msgToLower.Contains("has incomplete content"))
            {
                _validationError = GetErrorDescriptorForHasIncompleteContent(msg);
                processMessage = BuildProcessMessageDocument(MissingMandatoryMessage, msg + _validationError.Hint, _validationError.Code);
                _isValidationError = true;
            }
            else if (msgToLower.Contains("has invalid child element"))
            {
                _validationError = GetErrorDescriptorForHasInvalidChildElement(msg);
                var shortMessage = _validationError.Code == ErrorCode4 ? MissingMandatoryMessage : ContactYourProviderMsg;
                processMessage = BuildProcessMessageDocument(shortMessage, msg + _validationError.Hint, _validationError.Code);
                _isValidationError = true;
            }
            else
            {
                processMessage = BuildProcessMessageDocument(ContactYourProviderMsg, msg, ErrorCode1);
                _isValidationError = true;
            }

            this.ErrorMessages.Add(processMessage);
        }

        private ProcessMessageDocument BuildProcessMessageDocument(string shortDescription, string longDescription, string code)
        {
            return new ProcessMessageDocument()
            {
                Code = code,
                Description = shortDescription,
                LongDescription = longDescription,
                SeverityAsString = "Error",
                Location = GetCurrentLocation()
            };
        }

        private ProcessMessageDocument BuildProcessMessageDocument(ProcessMessageDocument processMessage, string newLocation)
        {
            return new ProcessMessageDocument()
            {
                Code = processMessage.Code,
                Description = processMessage.Description,
                LongDescription = processMessage.LongDescription,
                SeverityAsString = "Error",
                Location = newLocation
            };
        }

        private enum ErrorDescriptor
        {
            NoError = 0,
            MandatoryElementError,
            NonMandatoryElementError,
            UnknownElement,
            Duplicate
        }

        private struct ErrorMessageType
        {
            public string Hint, Code, ExpectedNextValidElement;
            public ErrorDescriptor Errno;

            public ErrorMessageType(ErrorDescriptor errorDescriptor)
            {
                Errno = errorDescriptor;
                Hint = "";
                Code = "";
                ExpectedNextValidElement = "";
            }

            public ErrorMessageType(ErrorDescriptor errorDescriptor, string hint, string code, string elementName)
            {
                Errno = errorDescriptor;
                Hint = hint;
                Code = code;
                ExpectedNextValidElement = elementName;
            }
        }

        private ErrorMessageType GetErrorDescriptorForHasIncompleteContent(string validationErrorMessage)
        {
            ErrorMessageType retval = new ErrorMessageType();
            if (string.IsNullOrWhiteSpace(validationErrorMessage)) return retval;

            validationErrorMessage = validationErrorMessage.Replace(" ", string.Empty);
            validationErrorMessage = validationErrorMessage.Replace("'", " ");
            var parts = validationErrorMessage.Split(' ');
            if (parts.Length != 9) return retval;

            var elementBeingProcessed = parts[1];
            var csvList = parts[5];

            retval = ParseHasIncompleteContentCVSList(csvList, elementBeingProcessed);
            return retval;
        }

        private ErrorMessageType GetErrorDescriptorForHasInvalidChildElement(string validationErrorMessage)
        {
            string msg = string.Empty;
            ErrorMessageType retval = new ErrorMessageType();
            if (string.IsNullOrWhiteSpace(validationErrorMessage)) return retval;

            validationErrorMessage = validationErrorMessage.Replace(" ", string.Empty);
            validationErrorMessage = validationErrorMessage.Replace("'", " ");
            var parts = validationErrorMessage.Split(' ');

            //decide which message format to process
            if (validationErrorMessage.ToLower().Contains("listofpossibleelements"))
            {
                if (parts.Length == 13 || parts.Length == 12 || parts.Length == 10)
                {
                    var csvList = parts[9];
                    var elementBeingProcessed = parts[1];
                    var invalidChildElementName = parts[5];
                    retval = ParseCvsListForHasInvalidChildElementLongFormat(csvList, invalidChildElementName, elementBeingProcessed);
                }

                return retval;
            }
            else
            {
                if (parts.Length != 9) return retval;
                var csvList = parts[5];
                var elementBeingProcessed = parts[1];
                var invalidChildElementName = parts[5];

                retval = ParseCvsListForHasInvalidChildElementLongFormat(csvList, invalidChildElementName, elementBeingProcessed);
            }
            return retval;
        }

        private ErrorMessageType ParseCvsListForHasInvalidChildElementShortFormat(string csvList, string invalidChildElementName, string elementBeingProcessed)
        {
            ErrorMessageType retval = new ErrorMessageType();

            if (!string.IsNullOrEmpty(csvList))
            {
                var lastElementInListOfPossibleElements = GetLastElementInCsvList(csvList);

                retval.Hint =
                    string.Format(
                        " Hint: while processing parent element [{0}] child element [{1}] was unexpected",
                        elementBeingProcessed, invalidChildElementName);
                retval.Code = ErrorCode1;
                retval.Errno = ErrorDescriptor.UnknownElement;
                retval.ExpectedNextValidElement = invalidChildElementName;
            }

            return retval;
        }

        private string GetLastElementInCsvList(string csvList)
        {
            var list = (csvList.Contains(','))
                ? new List<string>(csvList.Split(','))
                : new List<string> { csvList };

            string lastElement = list.Last();
            if (lastElement.EndsWith("...."))
            {
                list.RemoveAt(list.Count - 1);
            }

            return list.Last();
        }

        private ErrorMessageType ParseCvsListForHasInvalidChildElementLongFormat(string csvList, string invalidChildElementName, string elementBeingProcessed)
        {
            ErrorMessageType retval = new ErrorMessageType();

            if (!string.IsNullOrEmpty(csvList))
            {
                var lastElementInListOfPossibleElements = GetLastElementInCsvList(csvList);
                var elementList = new List<string>(_elementCsvList.Split(','));

                if (ContainsElementForElementBeingProcessed(elementList, elementBeingProcessed, invalidChildElementName))
                {
                    var indexOfElementBeingProcessed = GetIndexOfElementBeingProcessed(elementList, elementBeingProcessed);
                    var indexOfinvalidChildElementName = GetIndexOfElementUnderElementBeingProcessed(elementList, elementBeingProcessed, invalidChildElementName);
                    var indexOflastElementInListOfPossibleElements = GetIndexOfElementUnderElementBeingProcessed(elementList, elementBeingProcessed, lastElementInListOfPossibleElements);

                    if (indexOfinvalidChildElementName > indexOflastElementInListOfPossibleElements)
                    {
                        retval.Hint =
                            string.Format(
                                " Hint: while processing parent element [{0}] child mandatory element [{1}] was expected but not found",
                                elementBeingProcessed, lastElementInListOfPossibleElements);
                        retval.Code = ErrorCode4;
                        retval.Errno = ErrorDescriptor.MandatoryElementError;
                        retval.ExpectedNextValidElement = lastElementInListOfPossibleElements;
                    }
                    else
                    {
                        retval.Hint =
                            string.Format(
                                " Hint: while processing parent element [{0}] child non mandatory element [{1}] was unexpected",
                                elementBeingProcessed, invalidChildElementName);
                        retval.Code = ErrorCode1;
                        retval.Errno = (indexOfinvalidChildElementName != indexOflastElementInListOfPossibleElements) ? ErrorDescriptor.NonMandatoryElementError : ErrorDescriptor.Duplicate;
                        retval.ExpectedNextValidElement = invalidChildElementName;
                    }
                }
                else
                {
                    //this element is unknown to the schema.
                    retval.Hint =
                        string.Format(
                            " Hint: while processing parent element [{0}] child element [{1}] was unexpected",
                            elementBeingProcessed, invalidChildElementName);
                    retval.Code = ErrorCode1;
                    retval.Errno = ErrorDescriptor.UnknownElement;
                    retval.ExpectedNextValidElement = invalidChildElementName;
                }
            }

            return retval;
        }

        private int GetIndexOfElementUnderElementBeingProcessed(List<string> validElementList,
                                                                string elementBeingProcessed,
                                                                string elementName)
        {
            int result;

            string elementWithParentNameMatch = elementBeingProcessed + "#" + elementName;
            result = validElementList.IndexOf(elementWithParentNameMatch);

            if (result < 0)
            {
                result = validElementList.IndexOf(elementName);
            }

            return result;
        }

        private int GetIndexOfElementBeingProcessed(List<string> validElementList,
                                                    string elementBeingProcessed)
        {
            return validElementList.IndexOf(elementBeingProcessed);
        }

        private bool ContainsElementForElementBeingProcessed(List<string> validElementList,
                                                             string elementBeingProcessed,
                                                             string elementName)
        {
            return validElementList.Contains(elementBeingProcessed + "#" + elementName) || validElementList.Contains(elementName);
        }

        private ErrorMessageType ParseHasIncompleteContentCVSList(string csvList, string elementBeingProcessed)
        {
            ErrorMessageType retval = new ErrorMessageType();

            if (!string.IsNullOrEmpty(csvList))
            {
                var lastElementInListOfPossibleElements = GetLastElementInCsvList(csvList);

                retval.Hint =
                    string.Format(
                        " Hint: while processing parent element [{0}] child mandatory element [{1}] was not found",
                        elementBeingProcessed, lastElementInListOfPossibleElements);

                retval.Code = ErrorCode4;
                retval.Errno = ErrorDescriptor.MandatoryElementError;
                retval.ExpectedNextValidElement = lastElementInListOfPossibleElements;
            }
            return retval;
        }

        private void StartEndDateError(DateTime startDate, DateTime endDate)
        {
            ProcessMessageDocument processMessage;

            string longDescription = string.Format("End date is earlier than start date (state date = {0}, end date = {1})", startDate.ToString("yyyy-MM-dd"), endDate.ToString("yyyy-MM-dd"));

            processMessage = new ProcessMessageDocument()
            {
                Code = "CMN.ATO.GEN.XML06",
                Description = "End date is earlier than start date.",
                LongDescription = longDescription,
                SeverityAsString = "Error",
                Location = GetCurrentLocation(),
            };
            processMessage.Parameters = new ProcessMessageParameters();
            processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "startDate", Value = startDate.ToString("yyyy-MM-dd") });
            processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "endDate", Value = endDate.ToString("yyyy-MM-dd") });
            this.ErrorMessages.Add(processMessage);
        }

        private void StartEndDateError(DateTime? startDate, DateTime? endDate)
        {
            ProcessMessageDocument processMessage;

            if (startDate == null || endDate == null)
                return;

            string longDescription = string.Format("End date is earlier than start date (state date = {0}, end date = {1})", startDate.Value.ToString("yyyy-MM-dd"), endDate.Value.ToString("yyyy-MM-dd"));

            processMessage = new ProcessMessageDocument()
            {
                Code = "CMN.ATO.GEN.XML06",
                Description = "End date is earlier than start date.",
                LongDescription = longDescription,
                SeverityAsString = "Error",
                Location = GetCurrentLocation(),
            };
            processMessage.Parameters = new ProcessMessageParameters();
            processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "startDate", Value = startDate.Value.ToString("yyyy-MM-dd") });
            processMessage.Parameters.Add(new ProcessMessageParameter() { Name = "endDate", Value = endDate.Value.ToString("yyyy-MM-dd") });
            this.ErrorMessages.Add(processMessage);
        }

        #endregion  Xml Reader Settings

        #region IsEmptyOrNilElement
        private static bool IsEmptyOrNilElement(XmlReader reader)
        {
            bool emptyOrNil = false;
            if (reader.IsEmptyElement)
            {
                emptyOrNil = true;
            }
            else
            {
                if (reader.HasAttributes)
                {
                    string nilValue = reader.GetAttribute("nil", "http://www.w3.org/2001/XMLSchema-instance");
                    if (nilValue != null && nilValue.ToLowerInvariant() == "true" || nilValue == "1")
                    {
                        emptyOrNil = true;
                    }
                }
            }
            return emptyOrNil;
        }
        #endregion  IsEmptyOrNilElement

        #region ToBoolean
        private bool? ToBoolean(string str)
        {
            bool returnValue;
            string value = (str ?? "").Trim();
            if (value == "0" || value == "1")
                return Convert.ToBoolean(Convert.ToInt32(value));

            if (Boolean.TryParse(value, out returnValue))
                return returnValue;
            return null;
        }
        #endregion  ToBoolean

        #region MoveToContent
        public bool MoveToContent(XmlReader reader)
        {
            try
            {
                reader.MoveToContent();
                return true;
            }
            catch (XmlException ex)
            {
                ProcessMessageDocument processMessage;
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.XML01",
                    Description = ContactYourProviderMsg,
                    LongDescription = ex.Message,
                    SeverityAsString = "Error",
                };
                this.ErrorMessages.Add(processMessage);
                return false;
            }
        }
        #endregion  MoveToContent

        #region ReadToNextElement


        public bool ReadToNextElement(XmlReader reader, bool isMandatory)
        {
            return ReadToNextElement(reader);
        }

        public bool ReadToNextElement(XmlReader reader)
        {
            bool retval = false;

            if ((reader.EOF && !_isValidationError) || _isExiting)
            {
                return false; //do nothing
            }

            if (!_isValidationError)
            {
                retval = SetReaderToNextElement(reader); //position the reader on the next valid element
            }

            if (_isValidationError)
            {
                //process validation errors
                var expectedNextElement = (!string.IsNullOrEmpty(_validationError.ExpectedNextValidElement)) ? _validationError.ExpectedNextValidElement : reader.LocalName;
                var actualNextValidElement = reader.LocalName;
                var location = GetCurrentLocation();

                if (_validationError.Errno == ErrorDescriptor.Duplicate)
                {
                    location = _lastPath;
                }

                var xpath = RemoveLeadingAndTrailingSlashes(location);

                var element = GetElementDescriptor(xpath);

                if (_validationError.Errno == ErrorDescriptor.UnknownElement)
                {
                    //set the xpath for elements that are not known to the schema
                    location = "/" + element.Path + "/" + element.Prefix + ":" + _validationError.ExpectedNextValidElement;
                    _isExiting = true;
                }
                else if (_validationError.Errno == ErrorDescriptor.NonMandatoryElementError)
                {
                    //set the xpath for the optional element that caused a validation
                    location = "/" + element.Path + "/" + element.Prefix + ":" + reader.LocalName;
                    _isExiting = true;
                }
                else
                {
                    //decide if we have spooled to the missing mandatory element. 
                    _isExiting = expectedNextElement == element.PathLeafNode;
                }

                if (_isExiting)
                {
                    //The location has changed since detection of the validation error - so update it.
                    UpdateErrorMessageWithLocation(location);
                }

                return false;
            }

            //Save previous path so we can detect duplicate elements
            _lastPath = GetCurrentLocation();

            return retval;
        }

        private bool ReadNext(XmlReader reader)
        {
            return !reader.EOF && reader.Read();
        }

        private void UpdateErrorMessageWithLocation(string newLocation)
        {
            var lastProcessMessage = ErrorMessages.Last();
            ErrorMessages.Remove(lastProcessMessage);
            var newProcessMessage = BuildProcessMessageDocument(lastProcessMessage, newLocation);
            ErrorMessages.Add(newProcessMessage);
        }

        private string RemoveLeadingAndTrailingSlashes(string xpath)
        {
            var xpathLength = xpath.Length;
            if (xpathLength <= 0) return string.Empty;
            var firstChar = xpath.Substring(0, 1);
            var lastChar = xpath.Substring(xpathLength - 1, 1);
            if (firstChar == "/")
            {
                xpath = xpath.Remove(0, 1);
                xpathLength--;
            }
            if (lastChar == "/")
            {
                xpath = xpath.Remove(xpathLength - 1, 1);
            }
            return xpath;
        }

        private struct ElementDescriptor
        {
            public string Prefix, PathLeafNode, Path;
            public ElementDescriptor(string prefix, string leaf, string path)
            {
                Prefix = prefix;
                PathLeafNode = leaf;
                Path = path;
            }
        }

        private ElementDescriptor GetElementDescriptor(string xpath)
        {
            var retval = new ElementDescriptor();

            var parts = xpath.Split('/');
            var numberOfParts = parts.Length;
            if (numberOfParts > 0)
            {
                var leafNode = parts[numberOfParts - 1];
                var p = leafNode.Split(':');
                numberOfParts = p.Length;
                if (numberOfParts == 1)
                {
                    retval.PathLeafNode = p[0];
                    retval.Prefix = string.Empty;
                }
                else if (numberOfParts == 2)
                {
                    retval.PathLeafNode = p[1];
                    retval.Prefix = p[0];
                }
                var leafNodeLength = leafNode.Length;
                var path = xpath.Remove(xpath.Length - leafNodeLength, leafNodeLength);
                retval.Path = RemoveLeadingAndTrailingSlashes(path);
            }
            return retval;
        }

        private bool SetReaderToNextElement(XmlReader reader)
        {
            try
            {
                if (reader.EOF || _isExiting) return false;
                if (_found)
                {
                    reader.Read();
                    _found = false;
                }
                while (!reader.EOF && reader.NodeType != XmlNodeType.Element)
                {
                    reader.Read();
                }

                return reader.NodeType == XmlNodeType.Element && !reader.EOF;

            }
            catch (XmlException ex)
            {
                ProcessMessageDocument processMessage;
                processMessage = new ProcessMessageDocument()
                {
                    Code = ErrorCode1,
                    Description = ContactYourProviderMsg,
                    LongDescription = ex.Message,
                    SeverityAsString = "Error",
                };
                this.ErrorMessages.Add(processMessage);
                return false;
            }
        }

        #endregion  ReadToNextElement

        private Stack<string> _currentXPath = new Stack<string>();

        public ABNREGREQUEST2019 Consume(Stream streamToLoad, bool validateDataTypes = false)
        {
            ABNREGREQUEST2019 report = new ABNREGREQUEST2019();

            // Working Variable for if can still read from the xml stream
            bool reading;

            // Working Variables for current values
            string currentValue;
            DateTime currentDateTimeValue;
            bool? currentBooleanValue;
            decimal currentDecimalValue;
            double currentDoubleValue;
            float currentFloatValue;
            sbyte currentsByteValue;
            byte currentByteValue;
            short currentShortValue;
            ushort currentuShortValue;
            uint currentuIntValue;
            int currentIntValue;
            long currentLongValue;
            ulong currentuLongValue;

            this.ErrorMessages = new List<ProcessMessageDocument>();
            _currentXPath.Push("/tns:ABNREGREQUEST");

            if (streamToLoad == null || streamToLoad.Length == 0 || !streamToLoad.CanRead)
            {
                MissingElementError();
                return report;
            }

            streamToLoad.Position = 0;
            XmlReader reader;

            if (validateDataTypes)
                reader = XmlReader.Create(streamToLoad, GetValidatingReaderSettings());
            else
                reader = XmlReader.Create(streamToLoad, ReaderSettings);

            if (!MoveToContent(reader))
                return report;

            reading = !reader.EOF;

            if (ReadToNextElement(reader) && reader.LocalName == "ABNREGREQUEST" && reader.NamespaceURI == "http://www.sbr.gov.au/ato/abnregrequest")
            {
                _found = true;
                ReadToNextElement(reader);
            }
            else
            {
                MissingElementError();
                return report;
            }


            #region RP
            _currentXPath.Push("/tns:RP");
            //1. use case
            if (ReadToNextElement(reader, true) && reader.LocalName == "RP")
            {
                report.RPId = "RP";
                report.RPExists = true;
                report.RPCount += 1;
                report.RPOccurrenceIndex = report.RPCount;
                report.RPLastOccurrenceIndex = report.RPCount;

                _found = true;

                #region IdentifiersCallReferenceIdentifier
                _currentXPath.Push("/tns:IdentifiersCallReferenceIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersCallReferenceIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG1 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersCallReferenceIdentifier

                #region ElectronicContactElectronicServiceAddressText
                _currentXPath.Push("/tns:ElectronicContactElectronicServiceAddressText");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "ElectronicContactElectronicServiceAddressText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG3 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactElectronicServiceAddressText

                #region ElectronicContactDeviceTypeText
                _currentXPath.Push("/tns:ElectronicContactDeviceTypeText");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "ElectronicContactDeviceTypeText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG4 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactDeviceTypeText

                #region SoftwareInformationOperatingSystemText
                _currentXPath.Push("/tns:SoftwareInformationOperatingSystemText");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "SoftwareInformationOperatingSystemText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG5 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SoftwareInformationOperatingSystemText

                #region IdentifiersRequesterReferenceIdentifier
                _currentXPath.Push("/tns:IdentifiersRequesterReferenceIdentifier");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "IdentifiersRequesterReferenceIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG6 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersRequesterReferenceIdentifier

                #region IdentificationDetailsVerificationRequestCount
                _currentXPath.Push("/tns:IdentificationDetailsVerificationRequestCount");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "IdentificationDetailsVerificationRequestCount")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (Decimal.TryParse(currentValue, out currentDecimalValue))
                            {
                                report.ABNREG195 = currentDecimalValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentificationDetailsVerificationRequestCount

                #region PartyTypeCode
                _currentXPath.Push("/tns:PartyTypeCode");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "PartyTypeCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG7 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PartyTypeCode

                #region OrganisationDetailsOrganisationTypeCode
                _currentXPath.Push("/tns:OrganisationDetailsOrganisationTypeCode");
                //6. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "OrganisationDetailsOrganisationTypeCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG8 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsOrganisationTypeCode

                #region OrganisationDetailsAustralianBusinessRegisterEntityTypeCode
                _currentXPath.Push("/tns:OrganisationDetailsAustralianBusinessRegisterEntityTypeCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsAustralianBusinessRegisterEntityTypeCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG9 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsAustralianBusinessRegisterEntityTypeCode

                #region InteractionABNEntitlementIndicator
                _currentXPath.Push("/tns:InteractionABNEntitlementIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionABNEntitlementIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG15 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion InteractionABNEntitlementIndicator

                #region Entitlement

                _currentXPath.Push("/tns:EntitlementCollection");
                // 4. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "EntitlementCollection")
                {
                    report.EntitlementCollection = new List<ABNREGREQUEST2019.Entitlement>();
                    report.EntitlementCollectionExists = true;

                    _found = true;

                    while (ReadToNextElement(reader, false) && reader.LocalName == "Entitlement")
                    {
                        _found = true;

                        ABNREGREQUEST2019.Entitlement entitlement = new ABNREGREQUEST2019.Entitlement();
                        report.EntitlementCollection.Add(entitlement);
                        report.EntitlementCollectionCount += 1;
                        entitlement.OccurrenceIndex = report.EntitlementCollectionCount;

                        _currentXPath.Push("/tns:Entitlement[" + report.EntitlementCollectionCount + "]");

                        #region EntitlementQuestionInteractionQuestionIdentifier
                        _currentXPath.Push("/tns:EntitlementQuestionInteractionQuestionIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, true) && reader.LocalName == "EntitlementQuestionInteractionQuestionIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    entitlement.ABNREG11 = currentValue;
                                    entitlement.Entitlement_EntitlementQuestionCollectionExists = true;
                                    entitlement.Entitlement_EntitlementQuestionCollectionCount += 1;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion EntitlementQuestionInteractionQuestionIdentifier

                        #region InteractionOptionQuestionIdentifier
                        _currentXPath.Push("/tns:InteractionOptionQuestionIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, true) && reader.LocalName == "InteractionOptionQuestionIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    entitlement.ABNREG12 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion InteractionOptionQuestionIdentifier

                        #region EntitlementNextQuestionInteractionQuestionIdentifier
                        _currentXPath.Push("/tns:EntitlementNextQuestionInteractionQuestionIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "EntitlementNextQuestionInteractionQuestionIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    entitlement.ABNREG13 = currentValue;
                                    entitlement.Entitlement_EntitlementNextQuestionCollectionExists = true;
                                    entitlement.Entitlement_EntitlementNextQuestionCollectionCount += 1;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion EntitlementNextQuestionInteractionQuestionIdentifier
                        _currentXPath.Pop();
                    } // End of while loop for Entitlement
                } // End of if EntitlementCollection node exists

                _currentXPath.Pop();
                #endregion Entitlement

                #region IdentifiersTaxFileNumberInexistentIndicator
                _currentXPath.Push("/tns:IdentifiersTaxFileNumberInexistentIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxFileNumberInexistentIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG16 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersTaxFileNumberInexistentIndicator

                #region IdentifiersAustralianBusinessNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersAustralianBusinessNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianBusinessNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG17 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersAustralianBusinessNumberIdentifier

                #region InteractionABNApplicationIndicator
                _currentXPath.Push("/tns:InteractionABNApplicationIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionABNApplicationIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG18 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion InteractionABNApplicationIndicator

                #region InteractionTFNApplicationIndicator
                _currentXPath.Push("/tns:InteractionTFNApplicationIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionTFNApplicationIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG19 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion InteractionTFNApplicationIndicator

                #region PartyGovernmentTierCode
                _currentXPath.Push("/tns:PartyGovernmentTierCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PartyGovernmentTierCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG213 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PartyGovernmentTierCode

                #region OrganisationDetailsNotForProfitIndicator
                _currentXPath.Push("/tns:OrganisationDetailsNotForProfitIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsNotForProfitIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG21 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsNotForProfitIndicator

                #region IncomeTaxExemptionIndicator
                _currentXPath.Push("/tns:IncomeTaxExemptionIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxExemptionIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG22 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IncomeTaxExemptionIndicator

                #region IdentifiersTaxAgentNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersTaxAgentNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxAgentNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG23 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersTaxAgentNumberIdentifier

                #region SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount
                _currentXPath.Push("/tns:SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (Decimal.TryParse(currentValue, out currentDecimalValue))
                            {
                                report.ABNREG25 = currentDecimalValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount

                #region SuperannuationFundDetailsFundTypeCode
                _currentXPath.Push("/tns:SuperannuationFundDetailsFundTypeCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsFundTypeCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG26 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsFundTypeCode

                #region SuperannuationFundDetailsFundBenefitStructureCode
                _currentXPath.Push("/tns:SuperannuationFundDetailsFundBenefitStructureCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsFundBenefitStructureCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG27 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsFundBenefitStructureCode

                #region ResidencyTaxPurposesPersonStatusIndicator
                _currentXPath.Push("/tns:ResidencyTaxPurposesPersonStatusIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ResidencyTaxPurposesPersonStatusIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG28 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ResidencyTaxPurposesPersonStatusIndicator

                #region IdentifiersAustralianCompanyNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersAustralianCompanyNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianCompanyNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG29 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersAustralianCompanyNumberIdentifier

                #region IdentifiersAustralianRegisteredBodyNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersAustralianRegisteredBodyNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianRegisteredBodyNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG30 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersAustralianRegisteredBodyNumberIdentifier

                #region OrganisationNameDetailsOrganisationalNameText
                _currentXPath.Push("/tns:OrganisationNameDetailsOrganisationalNameText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationNameDetailsOrganisationalNameText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG31 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationNameDetailsOrganisationalNameText

                #region PersonDemographicDetailsBirthDate
                _currentXPath.Push("/tns:PersonDemographicDetailsBirthDate");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsBirthDate")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                            {
                                report.ABNREG34 = currentDateTimeValue.Date;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsBirthDate

                #region PersonNameDetailsFamilyNameText
                _currentXPath.Push("/tns:PersonNameDetailsFamilyNameText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsFamilyNameText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG35 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonNameDetailsFamilyNameText

                #region PersonNameDetailsGivenNameText
                _currentXPath.Push("/tns:PersonNameDetailsGivenNameText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsGivenNameText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG36 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonNameDetailsGivenNameText

                #region PersonNameDetailsOtherGivenNameText
                _currentXPath.Push("/tns:PersonNameDetailsOtherGivenNameText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsOtherGivenNameText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG37 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonNameDetailsOtherGivenNameText

                #region PersonNameDetailsTitleText
                _currentXPath.Push("/tns:PersonNameDetailsTitleText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsTitleText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG38 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonNameDetailsTitleText

                #region PersonDemographicDetailsSexCode
                _currentXPath.Push("/tns:PersonDemographicDetailsSexCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsSexCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG39 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsSexCode

                #region IdentifiersTaxFileNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersTaxFileNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxFileNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG40 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersTaxFileNumberIdentifier

                #region OrganisationDetailsAgricultureActivityIndicator
                _currentXPath.Push("/tns:OrganisationDetailsAgricultureActivityIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsAgricultureActivityIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG41 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsAgricultureActivityIndicator

                #region OrganisationDetailsGovernmentControlledOwnedIndicator
                _currentXPath.Push("/tns:OrganisationDetailsGovernmentControlledOwnedIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsGovernmentControlledOwnedIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG42 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsGovernmentControlledOwnedIndicator

                #region OrganisationDetailsMainIncomeActivityDescription
                _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityDescription");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityDescription")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG43 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsMainIncomeActivityDescription

                #region OrganisationDetailsMainIncomeActivityCode
                _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG44 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsMainIncomeActivityCode

                #region OrganisationDetailsOrganisationActivityStatusEndDate
                _currentXPath.Push("/tns:OrganisationDetailsOrganisationActivityStatusEndDate");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsOrganisationActivityStatusEndDate")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                            {
                                report.ABNREG45 = currentDateTimeValue.Date;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsOrganisationActivityStatusEndDate

                #region OrganisationDetailsOrganisationActivityStatusStartDate
                _currentXPath.Push("/tns:OrganisationDetailsOrganisationActivityStatusStartDate");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsOrganisationActivityStatusStartDate")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                            {
                                report.ABNREG46 = currentDateTimeValue.Date;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsOrganisationActivityStatusStartDate

                #region OrganisationDetailsMultipleBusinessLocationIndicator
                _currentXPath.Push("/tns:OrganisationDetailsMultipleBusinessLocationIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMultipleBusinessLocationIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG47 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsMultipleBusinessLocationIndicator

                #region ElectronicContactTelephoneServiceLineCode
                _currentXPath.Push("/tns:ElectronicContactTelephoneServiceLineCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneServiceLineCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG57 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactTelephoneServiceLineCode

                #region ElectronicContactTelephoneAreaCode
                _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG217 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactTelephoneAreaCode

                #region ElectronicContactTelephoneMinimalNumber
                _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG58 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactTelephoneMinimalNumber

                #region AdditionalBusinessLocation

                _currentXPath.Push("/tns:AdditionalBusinessLocationCollection");
                // 4. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "AdditionalBusinessLocationCollection")
                {
                    report.AdditionalBusinessLocationCollection = new List<ABNREGREQUEST2019.AdditionalBusinessLocation>();
                    report.AdditionalBusinessLocationCollectionExists = true;

                    _found = true;

                    while (ReadToNextElement(reader, false) && reader.LocalName == "AdditionalBusinessLocation")
                    {
                        _found = true;

                        ABNREGREQUEST2019.AdditionalBusinessLocation additionalBusinessLocation = new ABNREGREQUEST2019.AdditionalBusinessLocation();
                        report.AdditionalBusinessLocationCollection.Add(additionalBusinessLocation);
                        report.AdditionalBusinessLocationCollectionCount += 1;
                        additionalBusinessLocation.OccurrenceIndex = report.AdditionalBusinessLocationCollectionCount;

                        _currentXPath.Push("/tns:AdditionalBusinessLocation[" + report.AdditionalBusinessLocationCollectionCount + "]");

                        #region OrganisationDetailsMainBusinessActivityIndicator
                        _currentXPath.Push("/tns:OrganisationDetailsMainBusinessActivityIndicator");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainBusinessActivityIndicator")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    currentBooleanValue = ToBoolean(currentValue);
                                    if (currentBooleanValue != null)
                                    {
                                        additionalBusinessLocation.ABNREG225 = currentBooleanValue;
                                    }
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion OrganisationDetailsMainBusinessActivityIndicator

                        #region OrganisationDetailsMainIncomeActivityDescription
                        _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityDescription");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityDescription")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG66 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion OrganisationDetailsMainIncomeActivityDescription

                        #region OrganisationDetailsMainIncomeActivityCode
                        _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG67 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion OrganisationDetailsMainIncomeActivityCode

                        #region AddressDetailsLine1Text
                        _currentXPath.Push("/tns:AddressDetailsLine1Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine1Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG68 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine1Text

                        #region AddressDetailsLine2Text
                        _currentXPath.Push("/tns:AddressDetailsLine2Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine2Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG69 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine2Text

                        #region AddressDetailsCountryCode
                        _currentXPath.Push("/tns:AddressDetailsCountryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsCountryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG70 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsCountryCode

                        #region AddressDetailsPostcodeText
                        _currentXPath.Push("/tns:AddressDetailsPostcodeText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsPostcodeText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG71 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsPostcodeText

                        #region AddressDetailsStateOrTerritoryCode
                        _currentXPath.Push("/tns:AddressDetailsStateOrTerritoryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsStateOrTerritoryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG72 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsStateOrTerritoryCode

                        #region AddressDetailsLocalityNameText
                        _currentXPath.Push("/tns:AddressDetailsLocalityNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLocalityNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG73 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLocalityNameText

                        #region ElectronicContactElectronicMailAddressText
                        _currentXPath.Push("/tns:ElectronicContactElectronicMailAddressText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactElectronicMailAddressText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG75 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactElectronicMailAddressText

                        #region ElectronicContactTelephoneServiceLineCode
                        _currentXPath.Push("/tns:ElectronicContactTelephoneServiceLineCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneServiceLineCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG76 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactTelephoneServiceLineCode

                        #region ElectronicContactTelephoneAreaCode
                        _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG218 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactTelephoneAreaCode

                        #region ElectronicContactTelephoneMinimalNumber
                        _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    additionalBusinessLocation.ABNREG77 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactTelephoneMinimalNumber
                        _currentXPath.Pop();
                    } // End of while loop for AdditionalBusinessLocation
                } // End of if AdditionalBusinessLocationCollection node exists

                _currentXPath.Pop();
                #endregion AdditionalBusinessLocation

                #region AuthorisedContact

                _currentXPath.Push("/tns:AuthorisedContactCollection");
                // 4. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "AuthorisedContactCollection")
                {
                    report.AuthorisedContactCollection = new List<ABNREGREQUEST2019.AuthorisedContact>();
                    report.AuthorisedContactCollectionExists = true;

                    _found = true;

                    while (ReadToNextElement(reader, true) && reader.LocalName == "AuthorisedContact")
                    {
                        _found = true;

                        ABNREGREQUEST2019.AuthorisedContact authorisedContact = new ABNREGREQUEST2019.AuthorisedContact();
                        report.AuthorisedContactCollection.Add(authorisedContact);
                        report.AuthorisedContactCollectionCount += 1;
                        authorisedContact.OccurrenceIndex = report.AuthorisedContactCollectionCount;

                        _currentXPath.Push("/tns:AuthorisedContact[" + report.AuthorisedContactCollectionCount + "]");

                        #region PersonNameDetailsTitleText
                        _currentXPath.Push("/tns:PersonNameDetailsTitleText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsTitleText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG78 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsTitleText

                        #region PersonNameDetailsGivenNameText
                        _currentXPath.Push("/tns:PersonNameDetailsGivenNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsGivenNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG79 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsGivenNameText

                        #region PersonNameDetailsFamilyNameText
                        _currentXPath.Push("/tns:PersonNameDetailsFamilyNameText");
                        //6. use case
                        if (ReadToNextElement(reader, true) && reader.LocalName == "PersonNameDetailsFamilyNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG80 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsFamilyNameText

                        #region AfterhoursContactTelephone
                        _currentXPath.Push("/tns:AfterhoursContactTelephone");
                        //3. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AfterhoursContactTelephone")
                        {
                            authorisedContact.AuthorisedContact_AfterhoursContactTelephoneCollectionExists = true;
                            authorisedContact.AuthorisedContact_AfterhoursContactTelephoneCollectionCount += 1;
                            _found = true;

                            #region ElectronicContactTelephoneAreaCode
                            _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                            //6. use case
                            if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                        authorisedContact.ABNREG219 = currentValue;
                                    }
                                }
                                _found = true;
                            }

                            _currentXPath.Pop();
                            #endregion ElectronicContactTelephoneAreaCode

                            #region ElectronicContactTelephoneMinimalNumber
                            _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                            //6. use case
                            if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                        authorisedContact.ABNREG81 = currentValue;
                                    }
                                }
                                _found = true;
                            }

                            _currentXPath.Pop();
                            #endregion ElectronicContactTelephoneMinimalNumber
                        } // End of if AfterhoursContactTelephone node exists

                        _currentXPath.Pop();
                        #endregion AfterhoursContactTelephone

                        #region BusinessHoursContactTelephone
                        _currentXPath.Push("/tns:BusinessHoursContactTelephone");
                        //3. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "BusinessHoursContactTelephone")
                        {
                            authorisedContact.AuthorisedContact_BusinessHoursContactTelephoneCollectionExists = true;
                            authorisedContact.AuthorisedContact_BusinessHoursContactTelephoneCollectionCount += 1;
                            _found = true;

                            #region ElectronicContactTelephoneAreaCode
                            _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                            //6. use case
                            if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                        authorisedContact.ABNREG220 = currentValue;
                                    }
                                }
                                _found = true;
                            }

                            _currentXPath.Pop();
                            #endregion ElectronicContactTelephoneAreaCode

                            #region ElectronicContactTelephoneMinimalNumber
                            _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                            //6. use case
                            if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                        authorisedContact.ABNREG82 = currentValue;
                                    }
                                }
                                _found = true;
                            }

                            _currentXPath.Pop();
                            #endregion ElectronicContactTelephoneMinimalNumber
                        } // End of if BusinessHoursContactTelephone node exists

                        _currentXPath.Pop();
                        #endregion BusinessHoursContactTelephone

                        #region ElectronicContactElectronicMailAddressText
                        _currentXPath.Push("/tns:ElectronicContactElectronicMailAddressText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactElectronicMailAddressText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG83 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactElectronicMailAddressText

                        #region ElectronicContactFacsimileAreaCode
                        _currentXPath.Push("/tns:ElectronicContactFacsimileAreaCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactFacsimileAreaCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG224 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactFacsimileAreaCode

                        #region ElectronicContactFacsimileMinimalNumber
                        _currentXPath.Push("/tns:ElectronicContactFacsimileMinimalNumber");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactFacsimileMinimalNumber")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG84 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactFacsimileMinimalNumber

                        #region ElectronicContactTelephoneMobileNumber
                        _currentXPath.Push("/tns:ElectronicContactTelephoneMobileNumber");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMobileNumber")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG85 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion ElectronicContactTelephoneMobileNumber

                        #region PersonDemographicDetailsLanguagePreferredCode
                        _currentXPath.Push("/tns:PersonDemographicDetailsLanguagePreferredCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsLanguagePreferredCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG86 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonDemographicDetailsLanguagePreferredCode

                        #region PersonDemographicDetailsLanguagePreferredOtherDescription
                        _currentXPath.Push("/tns:PersonDemographicDetailsLanguagePreferredOtherDescription");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsLanguagePreferredOtherDescription")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG87 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonDemographicDetailsLanguagePreferredOtherDescription

                        #region PersonNameDetailsPositionText
                        _currentXPath.Push("/tns:PersonNameDetailsPositionText");
                        //6. use case
                        if (ReadToNextElement(reader, true) && reader.LocalName == "PersonNameDetailsPositionText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    authorisedContact.ABNREG88 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsPositionText
                        _currentXPath.Pop();
                    } // End of while loop for AuthorisedContact
                } // End of if AuthorisedContactCollection node exists

                _currentXPath.Pop();
                #endregion AuthorisedContact

                #region AssociateIndividual

                _currentXPath.Push("/tns:AssociateIndividualCollection");
                // 4. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "AssociateIndividualCollection")
                {
                    report.AssociateIndividualCollection = new List<ABNREGREQUEST2019.AssociateIndividual>();
                    report.AssociateIndividualCollectionExists = true;

                    _found = true;

                    while (ReadToNextElement(reader, false) && reader.LocalName == "AssociateIndividual")
                    {
                        _found = true;

                        ABNREGREQUEST2019.AssociateIndividual associateIndividual = new ABNREGREQUEST2019.AssociateIndividual();
                        report.AssociateIndividualCollection.Add(associateIndividual);
                        report.AssociateIndividualCollectionCount += 1;
                        associateIndividual.OccurrenceIndex = report.AssociateIndividualCollectionCount;

                        _currentXPath.Push("/tns:AssociateIndividual[" + report.AssociateIndividualCollectionCount + "]");

                        #region PersonDemographicDetailsBirthDate
                        _currentXPath.Push("/tns:PersonDemographicDetailsBirthDate");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsBirthDate")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                    {
                                        associateIndividual.ABNREG89 = currentDateTimeValue.Date;
                                    }
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonDemographicDetailsBirthDate

                        #region PersonNameDetailsFamilyNameText
                        _currentXPath.Push("/tns:PersonNameDetailsFamilyNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsFamilyNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG90 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsFamilyNameText

                        #region PersonNameDetailsGivenNameText
                        _currentXPath.Push("/tns:PersonNameDetailsGivenNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsGivenNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG91 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsGivenNameText

                        #region PersonNameDetailsOtherGivenNameText
                        _currentXPath.Push("/tns:PersonNameDetailsOtherGivenNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsOtherGivenNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG92 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsOtherGivenNameText

                        #region PersonNameDetailsTitleText
                        _currentXPath.Push("/tns:PersonNameDetailsTitleText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsTitleText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG93 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonNameDetailsTitleText

                        #region PersonDemographicDetailsSexCode
                        _currentXPath.Push("/tns:PersonDemographicDetailsSexCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsSexCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG94 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PersonDemographicDetailsSexCode

                        #region PersonNameDetailsPositionTextCollection
                        _currentXPath.Push("/tns:PersonNameDetailsPositionTextCollection");
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionTextCollection")
                        {
                            associateIndividual.ABNREG95Collection = new List<string>();
                            ReadNext(reader);
                            _currentXPath.Push("/tns:PersonNameDetailsPositionText");
                            // 5. use case
                            while (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionText")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before the currentXPath is updated.
                                        associateIndividual.ABNREG95Collection.Add(currentValue);
                                    }
                                }
                                _found = true;
                            }
                            _currentXPath.Pop();
                        }
                        _currentXPath.Pop();
                        #endregion PersonNameDetailsPositionTextCollection

                        #region IdentifiersTaxFileNumberIdentifier
                        _currentXPath.Push("/tns:IdentifiersTaxFileNumberIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxFileNumberIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG96 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion IdentifiersTaxFileNumberIdentifier

                        #region AddressDetailsLine1Text
                        _currentXPath.Push("/tns:AddressDetailsLine1Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine1Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG97 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine1Text

                        #region AddressDetailsLine2Text
                        _currentXPath.Push("/tns:AddressDetailsLine2Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine2Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG98 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine2Text

                        #region AddressDetailsLocalityNameText
                        _currentXPath.Push("/tns:AddressDetailsLocalityNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLocalityNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG99 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLocalityNameText

                        #region AddressDetailsPostcodeText
                        _currentXPath.Push("/tns:AddressDetailsPostcodeText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsPostcodeText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG100 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsPostcodeText

                        #region AddressDetailsStateOrTerritoryCode
                        _currentXPath.Push("/tns:AddressDetailsStateOrTerritoryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsStateOrTerritoryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG101 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsStateOrTerritoryCode

                        #region AddressDetailsCountryCode
                        _currentXPath.Push("/tns:AddressDetailsCountryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsCountryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateIndividual.ABNREG102 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsCountryCode
                        _currentXPath.Pop();
                    } // End of while loop for AssociateIndividual
                } // End of if AssociateIndividualCollection node exists

                _currentXPath.Pop();
                #endregion AssociateIndividual

                #region AssociateOrganisation

                _currentXPath.Push("/tns:AssociateOrganisationCollection");
                // 4. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "AssociateOrganisationCollection")
                {
                    report.AssociateOrganisationCollection = new List<ABNREGREQUEST2019.AssociateOrganisation>();
                    report.AssociateOrganisationCollectionExists = true;

                    _found = true;

                    while (ReadToNextElement(reader, false) && reader.LocalName == "AssociateOrganisation")
                    {
                        _found = true;

                        ABNREGREQUEST2019.AssociateOrganisation associateOrganisation = new ABNREGREQUEST2019.AssociateOrganisation();
                        report.AssociateOrganisationCollection.Add(associateOrganisation);
                        report.AssociateOrganisationCollectionCount += 1;
                        associateOrganisation.OccurrenceIndex = report.AssociateOrganisationCollectionCount;

                        _currentXPath.Push("/tns:AssociateOrganisation[" + report.AssociateOrganisationCollectionCount + "]");

                        #region IdentifiersAustralianCompanyNumberIdentifier
                        _currentXPath.Push("/tns:IdentifiersAustralianCompanyNumberIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianCompanyNumberIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG106 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion IdentifiersAustralianCompanyNumberIdentifier

                        #region IdentifiersAustralianRegisteredBodyNumberIdentifier
                        _currentXPath.Push("/tns:IdentifiersAustralianRegisteredBodyNumberIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianRegisteredBodyNumberIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG107 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion IdentifiersAustralianRegisteredBodyNumberIdentifier

                        #region OrganisationNameDetailsOrganisationalNameText
                        _currentXPath.Push("/tns:OrganisationNameDetailsOrganisationalNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationNameDetailsOrganisationalNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG108 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion OrganisationNameDetailsOrganisationalNameText

                        #region IdentifiersAustralianBusinessNumberIdentifier
                        _currentXPath.Push("/tns:IdentifiersAustralianBusinessNumberIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianBusinessNumberIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG109 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion IdentifiersAustralianBusinessNumberIdentifier

                        #region PersonNameDetailsPositionTextCollection
                        _currentXPath.Push("/tns:PersonNameDetailsPositionTextCollection");
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionTextCollection")
                        {
                            associateOrganisation.ABNREG110Collection = new List<string>();
                            ReadNext(reader);
                            _currentXPath.Push("/tns:PersonNameDetailsPositionText");
                            // 5. use case
                            while (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionText")
                            {
                                if (!IsEmptyOrNilElement(reader))
                                {
                                    ReadNext(reader);
                                    if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                    {
                                        currentValue = reader.Value;
                                        ReadNext(reader); // consume the end element so we detect any validation errors before the currentXPath is updated.
                                        associateOrganisation.ABNREG110Collection.Add(currentValue);
                                    }
                                }
                                _found = true;
                            }
                            _currentXPath.Pop();
                        }
                        _currentXPath.Pop();
                        #endregion PersonNameDetailsPositionTextCollection

                        #region IdentifiersTaxFileNumberIdentifier
                        _currentXPath.Push("/tns:IdentifiersTaxFileNumberIdentifier");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxFileNumberIdentifier")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG111 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion IdentifiersTaxFileNumberIdentifier

                        #region PeriodStartDate
                        _currentXPath.Push("/tns:PeriodStartDate");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "PeriodStartDate")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                    {
                                        associateOrganisation.ABNREG112 = currentDateTimeValue.Date;
                                    }
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion PeriodStartDate

                        #region AddressDetailsLine1Text
                        _currentXPath.Push("/tns:AddressDetailsLine1Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine1Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG113 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine1Text

                        #region AddressDetailsLine2Text
                        _currentXPath.Push("/tns:AddressDetailsLine2Text");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLine2Text")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG114 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLine2Text

                        #region AddressDetailsLocalityNameText
                        _currentXPath.Push("/tns:AddressDetailsLocalityNameText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsLocalityNameText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG115 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsLocalityNameText

                        #region AddressDetailsPostcodeText
                        _currentXPath.Push("/tns:AddressDetailsPostcodeText");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsPostcodeText")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG116 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsPostcodeText

                        #region AddressDetailsStateOrTerritoryCode
                        _currentXPath.Push("/tns:AddressDetailsStateOrTerritoryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsStateOrTerritoryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG117 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsStateOrTerritoryCode

                        #region AddressDetailsCountryCode
                        _currentXPath.Push("/tns:AddressDetailsCountryCode");
                        //6. use case
                        if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsCountryCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                    associateOrganisation.ABNREG118 = currentValue;
                                }
                            }
                            _found = true;
                        }

                        _currentXPath.Pop();
                        #endregion AddressDetailsCountryCode
                        _currentXPath.Pop();
                    } // End of while loop for AssociateOrganisation
                } // End of if AssociateOrganisationCollection node exists

                _currentXPath.Pop();
                #endregion AssociateOrganisation

                #region OrganisationDetailsRegisteredLegalEntityIndicator
                _currentXPath.Push("/tns:OrganisationDetailsRegisteredLegalEntityIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsRegisteredLegalEntityIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG119 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsRegisteredLegalEntityIndicator

                #region InteractionABNApplicationReasonCode
                _currentXPath.Push("/tns:InteractionABNApplicationReasonCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionABNApplicationReasonCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG120 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion InteractionABNApplicationReasonCode

                #region PersonDemographicDetailsFirstTimeDirectorIndicator
                _currentXPath.Push("/tns:PersonDemographicDetailsFirstTimeDirectorIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsFirstTimeDirectorIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG123 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsFirstTimeDirectorIndicator

                #region PersonDemographicDetailsFirstTimeContractorIndicator
                _currentXPath.Push("/tns:PersonDemographicDetailsFirstTimeContractorIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsFirstTimeContractorIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG124 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsFirstTimeContractorIndicator

                #region PersonDemographicDetailsFirstTimeSelfEmployedIndicator
                _currentXPath.Push("/tns:PersonDemographicDetailsFirstTimeSelfEmployedIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsFirstTimeSelfEmployedIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG125 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsFirstTimeSelfEmployedIndicator

                #region PersonDemographicDetailsGoverningRulesIndicator
                _currentXPath.Push("/tns:PersonDemographicDetailsGoverningRulesIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonDemographicDetailsGoverningRulesIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG126 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonDemographicDetailsGoverningRulesIndicator

                #region SuperannuationRegulatoryInformationElectionDate
                _currentXPath.Push("/tns:SuperannuationRegulatoryInformationElectionDate");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationRegulatoryInformationElectionDate")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                            {
                                report.ABNREG127 = currentDateTimeValue.Date;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationRegulatoryInformationElectionDate

                #region SuperannuationFundDetailsAgePensionFundIndicator
                _currentXPath.Push("/tns:SuperannuationFundDetailsAgePensionFundIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsAgePensionFundIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG128 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsAgePensionFundIndicator

                #region OrganisationDetailsLiquidatorAppointedIndicator
                _currentXPath.Push("/tns:OrganisationDetailsLiquidatorAppointedIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsLiquidatorAppointedIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG129 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsLiquidatorAppointedIndicator

                #region OrganisationDetailsDisqualifiedOfficerIndicator
                _currentXPath.Push("/tns:OrganisationDetailsDisqualifiedOfficerIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsDisqualifiedOfficerIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG130 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsDisqualifiedOfficerIndicator

                #region OrganisationDetailsReceiverAppointedIndicator
                _currentXPath.Push("/tns:OrganisationDetailsReceiverAppointedIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsReceiverAppointedIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG131 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsReceiverAppointedIndicator

                #region SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator
                _currentXPath.Push("/tns:SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG132 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator

                #region SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator
                _currentXPath.Push("/tns:SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG133 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator

                #region OrganisationDetailsCivilPenaltyOrderIndicator
                _currentXPath.Push("/tns:OrganisationDetailsCivilPenaltyOrderIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsCivilPenaltyOrderIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG134 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsCivilPenaltyOrderIndicator

                #region OrganisationDetailsConvictionIndicator
                _currentXPath.Push("/tns:OrganisationDetailsConvictionIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsConvictionIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG135 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsConvictionIndicator

                #region SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator
                _currentXPath.Push("/tns:SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG136 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator

                #region OrganisationDetailsOperationCeaseIndicator
                _currentXPath.Push("/tns:OrganisationDetailsOperationCeaseIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsOperationCeaseIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG137 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationDetailsOperationCeaseIndicator

                #region OrganisationControlCompanyOfficialManagementIndicator
                _currentXPath.Push("/tns:OrganisationControlCompanyOfficialManagementIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationControlCompanyOfficialManagementIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG138 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion OrganisationControlCompanyOfficialManagementIndicator

                #region UltimateHoldingCompany
                _currentXPath.Push("/tns:UltimateHoldingCompany");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "UltimateHoldingCompany")
                {
                    report.RPUltimateHoldingCompanyId = "UltimateHoldingCompany";
                    report.RPUltimateHoldingCompanyExists = true;
                    report.RPUltimateHoldingCompanyCount += 1;
                    report.RPUltimateHoldingCompanyOccurrenceIndex = report.RPUltimateHoldingCompanyCount;
                    report.RPUltimateHoldingCompanyLastOccurrenceIndex = report.RPUltimateHoldingCompanyCount;

                    _found = true;

                    #region IdentifiersAustralianCompanyNumberIdentifier
                    _currentXPath.Push("/tns:IdentifiersAustralianCompanyNumberIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianCompanyNumberIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG32 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IdentifiersAustralianCompanyNumberIdentifier

                    #region IdentifiersAustralianRegisteredBodyNumberIdentifier
                    _currentXPath.Push("/tns:IdentifiersAustralianRegisteredBodyNumberIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianRegisteredBodyNumberIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG33 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IdentifiersAustralianRegisteredBodyNumberIdentifier
                } // End of if UltimateHoldingCompany node exists

                _currentXPath.Pop();
                #endregion UltimateHoldingCompany

                #region AddressDetailsBusiness
                _currentXPath.Push("/tns:AddressDetailsBusiness");
                //1. use case
                if (ReadToNextElement(reader, true) && reader.LocalName == "AddressDetailsBusiness")
                {
                    report.RPAddressDetailsBUSId = "AddressDetailsBusiness";
                    report.RPAddressDetailsBUSExists = true;
                    report.RPAddressDetailsBUSCount += 1;
                    report.RPAddressDetailsBUSOccurrenceIndex = report.RPAddressDetailsBUSCount;
                    report.RPAddressDetailsBUSLastOccurrenceIndex = report.RPAddressDetailsBUSCount;

                    _found = true;

                    #region OrganisationDetailsMainBusinessActivityIndicator
                    _currentXPath.Push("/tns:OrganisationDetailsMainBusinessActivityIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainBusinessActivityIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG214 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion OrganisationDetailsMainBusinessActivityIndicator

                    #region OrganisationDetailsMainIncomeActivityDescription
                    _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityDescription");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityDescription")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG215 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion OrganisationDetailsMainIncomeActivityDescription

                    #region OrganisationDetailsMainIncomeActivityCode
                    _currentXPath.Push("/tns:OrganisationDetailsMainIncomeActivityCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsMainIncomeActivityCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG216 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion OrganisationDetailsMainIncomeActivityCode

                    #region Line1Text
                    _currentXPath.Push("/tns:Line1Text");
                    //6. use case
                    if (ReadToNextElement(reader, true) && reader.LocalName == "Line1Text")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG48 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion Line1Text

                    #region Line2Text
                    _currentXPath.Push("/tns:Line2Text");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "Line2Text")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG49 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion Line2Text

                    #region CountryCode
                    _currentXPath.Push("/tns:CountryCode");
                    //6. use case
                    if (ReadToNextElement(reader, true) && reader.LocalName == "CountryCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG50 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion CountryCode

                    #region PostcodeText
                    _currentXPath.Push("/tns:PostcodeText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "PostcodeText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG51 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion PostcodeText

                    #region StateOrTerritoryCode
                    _currentXPath.Push("/tns:StateOrTerritoryCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "StateOrTerritoryCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG52 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion StateOrTerritoryCode

                    #region LocalityNameText
                    _currentXPath.Push("/tns:LocalityNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LocalityNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG53 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LocalityNameText
                } // End of if AddressDetailsBusiness node exists

                _currentXPath.Pop();
                #endregion AddressDetailsBusiness

                #region Correspondence
                _currentXPath.Push("/tns:Correspondence");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "Correspondence")
                {
                    report.RPCorrespondenceId = "Correspondence";
                    report.RPCorrespondenceExists = true;
                    report.RPCorrespondenceCount += 1;
                    report.RPCorrespondenceOccurrenceIndex = report.RPCorrespondenceCount;
                    report.RPCorrespondenceLastOccurrenceIndex = report.RPCorrespondenceCount;

                    _found = true;

                    #region AddressText
                    _currentXPath.Push("/tns:AddressText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "AddressText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG55 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion AddressText
                } // End of if Correspondence node exists

                _currentXPath.Pop();
                #endregion Correspondence

                #region ElectronicContactElectronicMailBusiness
                _currentXPath.Push("/tns:ElectronicContactElectronicMailBusiness");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactElectronicMailBusiness")
                {
                    report.RPElectronicContactElectronicMailBUSId = "ElectronicContactElectronicMailBusiness";
                    report.RPElectronicContactElectronicMailBUSExists = true;
                    report.RPElectronicContactElectronicMailBUSCount += 1;
                    report.RPElectronicContactElectronicMailBUSOccurrenceIndex = report.RPElectronicContactElectronicMailBUSCount;
                    report.RPElectronicContactElectronicMailBUSLastOccurrenceIndex = report.RPElectronicContactElectronicMailBUSCount;

                    _found = true;

                    #region AddressText
                    _currentXPath.Push("/tns:AddressText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "AddressText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG56 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion AddressText
                } // End of if ElectronicContactElectronicMailBusiness node exists

                _currentXPath.Pop();
                #endregion ElectronicContactElectronicMailBusiness

                #region AddressDetailsPostal
                _currentXPath.Push("/tns:AddressDetailsPostal");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "AddressDetailsPostal")
                {
                    report.RPAddressDetailsPOSId = "AddressDetailsPostal";
                    report.RPAddressDetailsPOSExists = true;
                    report.RPAddressDetailsPOSCount += 1;
                    report.RPAddressDetailsPOSOccurrenceIndex = report.RPAddressDetailsPOSCount;
                    report.RPAddressDetailsPOSLastOccurrenceIndex = report.RPAddressDetailsPOSCount;

                    _found = true;

                    #region Line1Text
                    _currentXPath.Push("/tns:Line1Text");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "Line1Text")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG59 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion Line1Text

                    #region Line2Text
                    _currentXPath.Push("/tns:Line2Text");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "Line2Text")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG60 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion Line2Text

                    #region CountryCode
                    _currentXPath.Push("/tns:CountryCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "CountryCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG61 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion CountryCode

                    #region PostcodeText
                    _currentXPath.Push("/tns:PostcodeText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "PostcodeText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG62 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion PostcodeText

                    #region StateOrTerritoryCode
                    _currentXPath.Push("/tns:StateOrTerritoryCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "StateOrTerritoryCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG63 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion StateOrTerritoryCode

                    #region LocalityNameText
                    _currentXPath.Push("/tns:LocalityNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LocalityNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG64 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LocalityNameText
                } // End of if AddressDetailsPostal node exists

                _currentXPath.Pop();
                #endregion AddressDetailsPostal

                #region AUSkey
                _currentXPath.Push("/tns:AUSkey");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "AUSkey")
                {
                    report.RPAUSkeyId = "AUSkey";
                    report.RPAUSkeyExists = true;
                    report.RPAUSkeyCount += 1;
                    report.RPAUSkeyOccurrenceIndex = report.RPAUSkeyCount;
                    report.RPAUSkeyLastOccurrenceIndex = report.RPAUSkeyCount;

                    _found = true;

                    #region InteractionAUSKeyApplicationIndicator
                    _currentXPath.Push("/tns:InteractionAUSKeyApplicationIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionAUSKeyApplicationIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG103 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion InteractionAUSKeyApplicationIndicator

                    #region ElectronicContactElectronicMailAddressText
                    _currentXPath.Push("/tns:ElectronicContactElectronicMailAddressText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactElectronicMailAddressText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG104 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactElectronicMailAddressText

                    #region ElectronicContactTelephoneCountryCode
                    _currentXPath.Push("/tns:ElectronicContactTelephoneCountryCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneCountryCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG205 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactTelephoneCountryCode

                    #region ElectronicContactTelephoneAreaCode
                    _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG221 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactTelephoneAreaCode

                    #region ElectronicContactTelephoneMinimalNumber
                    _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG105 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactTelephoneMinimalNumber
                } // End of if AUSkey node exists

                _currentXPath.Pop();
                #endregion AUSkey

                #region Previous
                _currentXPath.Push("/tns:Previous");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "Previous")
                {
                    report.RPPreviousId = "Previous";
                    report.RPPreviousExists = true;
                    report.RPPreviousCount += 1;
                    report.RPPreviousOccurrenceIndex = report.RPPreviousCount;
                    report.RPPreviousLastOccurrenceIndex = report.RPPreviousCount;

                    _found = true;

                    #region IdentifiersAustralianBusinessNumberIdentifier
                    _currentXPath.Push("/tns:IdentifiersAustralianBusinessNumberIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianBusinessNumberIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG121 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IdentifiersAustralianBusinessNumberIdentifier
                } // End of if Previous node exists

                _currentXPath.Pop();
                #endregion Previous

                #region BusinessPrev
                _currentXPath.Push("/tns:BusinessPrev");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "BusinessPrev")
                {
                    report.RPBusinessPrevId = "BusinessPrev";
                    report.RPBusinessPrevExists = true;
                    report.RPBusinessPrevCount += 1;
                    report.RPBusinessPrevOccurrenceIndex = report.RPBusinessPrevCount;
                    report.RPBusinessPrevLastOccurrenceIndex = report.RPBusinessPrevCount;

                    _found = true;

                    #region IdentifiersAustralianBusinessNumberIdentifier
                    _currentXPath.Push("/tns:IdentifiersAustralianBusinessNumberIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianBusinessNumberIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG122 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IdentifiersAustralianBusinessNumberIdentifier
                } // End of if BusinessPrev node exists

                _currentXPath.Pop();
                #endregion BusinessPrev

                #region GST
                _currentXPath.Push("/tns:GST");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "GST")
                {
                    report.RPGSTId = "GST";
                    report.RPGSTExists = true;
                    report.RPGSTCount += 1;
                    report.RPGSTOccurrenceIndex = report.RPGSTCount;
                    report.RPGSTLastOccurrenceIndex = report.RPGSTCount;

                    _found = true;

                    #region GoodsAndServicesTaxRegistrationReasonCode
                    _currentXPath.Push("/tns:GoodsAndServicesTaxRegistrationReasonCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "GoodsAndServicesTaxRegistrationReasonCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG139 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion GoodsAndServicesTaxRegistrationReasonCode

                    #region GoodsAndServicesTaxRegistrationStartDate
                    _currentXPath.Push("/tns:GoodsAndServicesTaxRegistrationStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "GoodsAndServicesTaxRegistrationStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG140 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion GoodsAndServicesTaxRegistrationStartDate

                    #region GoodsAndServicesTaxTurnoverRangeCode
                    _currentXPath.Push("/tns:GoodsAndServicesTaxTurnoverRangeCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "GoodsAndServicesTaxTurnoverRangeCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG141 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion GoodsAndServicesTaxTurnoverRangeCode

                    #region LodgmentFrequencyCode
                    _currentXPath.Push("/tns:LodgmentFrequencyCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LodgmentFrequencyCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG142 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LodgmentFrequencyCode

                    #region AccountingPoliciesCashAccountingMethodUsedIndicator
                    _currentXPath.Push("/tns:AccountingPoliciesCashAccountingMethodUsedIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "AccountingPoliciesCashAccountingMethodUsedIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG143 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion AccountingPoliciesCashAccountingMethodUsedIndicator

                    #region GoodsAndServicesTaxImportIndicator
                    _currentXPath.Push("/tns:GoodsAndServicesTaxImportIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "GoodsAndServicesTaxImportIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG144 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion GoodsAndServicesTaxImportIndicator

                    #region FinancialInstitutionAccountBankStateBranchNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountBankStateBranchNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountBankStateBranchNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG145 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountBankStateBranchNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG146 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNameText
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG147 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNameText

                    #region FinancialInstitutionAccountHolderTypeCode
                    _currentXPath.Push("/tns:FinancialInstitutionAccountHolderTypeCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountHolderTypeCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG148 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountHolderTypeCode
                } // End of if GST node exists

                _currentXPath.Pop();
                #endregion GST

                #region FTC
                _currentXPath.Push("/tns:FTC");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "FTC")
                {
                    report.RPFTCId = "FTC";
                    report.RPFTCExists = true;
                    report.RPFTCCount += 1;
                    report.RPFTCOccurrenceIndex = report.RPFTCCount;
                    report.RPFTCLastOccurrenceIndex = report.RPFTCCount;

                    _found = true;

                    #region FuelTaxRegistrationStartDate
                    _currentXPath.Push("/tns:FuelTaxRegistrationStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FuelTaxRegistrationStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG149 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FuelTaxRegistrationStartDate

                    #region FuelTaxFuelTypeCodeCollection
                    _currentXPath.Push("/tns:FuelTaxFuelTypeCodeCollection");
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FuelTaxFuelTypeCodeCollection")
                    {
                        report.ABNREG150Collection = new List<string>();
                        ReadNext(reader);
                        _currentXPath.Push("/tns:FuelTaxFuelTypeCode");
                        // 5. use case
                        while (ReadToNextElement(reader, false) && reader.LocalName == "FuelTaxFuelTypeCode")
                        {
                            if (!IsEmptyOrNilElement(reader))
                            {
                                ReadNext(reader);
                                if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                                {
                                    currentValue = reader.Value;
                                    ReadNext(reader); // consume the end element so we detect any validation errors before the currentXPath is updated.
                                    report.ABNREG150Collection.Add(currentValue);
                                }
                            }
                            _found = true;
                        }
                        _currentXPath.Pop();
                    }
                    _currentXPath.Pop();
                    #endregion FuelTaxFuelTypeCodeCollection

                    #region FuelTaxHeavyVehicleIndicator
                    _currentXPath.Push("/tns:FuelTaxHeavyVehicleIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FuelTaxHeavyVehicleIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG151 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FuelTaxHeavyVehicleIndicator
                } // End of if FTC node exists

                _currentXPath.Pop();
                #endregion FTC

                #region LCT
                _currentXPath.Push("/tns:LCT");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "LCT")
                {
                    report.RPLCTId = "LCT";
                    report.RPLCTExists = true;
                    report.RPLCTCount += 1;
                    report.RPLCTOccurrenceIndex = report.RPLCTCount;
                    report.RPLCTLastOccurrenceIndex = report.RPLCTCount;

                    _found = true;

                    #region LuxuryCarTaxRegistrationRequiredIndicator
                    _currentXPath.Push("/tns:LuxuryCarTaxRegistrationRequiredIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxRegistrationRequiredIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG193 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxRegistrationRequiredIndicator

                    #region LuxuryCarTaxActivityCode
                    _currentXPath.Push("/tns:LuxuryCarTaxActivityCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxActivityCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG152 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxActivityCode

                    #region LuxuryCarTaxLiabilityRangeCode
                    _currentXPath.Push("/tns:LuxuryCarTaxLiabilityRangeCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxLiabilityRangeCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG153 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxLiabilityRangeCode

                    #region LuxuryCarTaxRegistrationStartDate
                    _currentXPath.Push("/tns:LuxuryCarTaxRegistrationStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxRegistrationStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG154 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxRegistrationStartDate

                    #region LuxuryCarTaxManufacturingPercent
                    _currentXPath.Push("/tns:LuxuryCarTaxManufacturingPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxManufacturingPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG155 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxManufacturingPercent

                    #region LuxuryCarTaxWholesalePercent
                    _currentXPath.Push("/tns:LuxuryCarTaxWholesalePercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxWholesalePercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG156 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxWholesalePercent

                    #region LuxuryCarTaxImportingPercent
                    _currentXPath.Push("/tns:LuxuryCarTaxImportingPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxImportingPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG157 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxImportingPercent

                    #region LuxuryCarTaxRetailingPercent
                    _currentXPath.Push("/tns:LuxuryCarTaxRetailingPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxRetailingPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG158 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxRetailingPercent

                    #region LuxuryCarTaxActivityStatementRegistrationIndicator
                    _currentXPath.Push("/tns:LuxuryCarTaxActivityStatementRegistrationIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LuxuryCarTaxActivityStatementRegistrationIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG159 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LuxuryCarTaxActivityStatementRegistrationIndicator
                } // End of if LCT node exists

                _currentXPath.Pop();
                #endregion LCT

                #region WET
                _currentXPath.Push("/tns:WET");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "WET")
                {
                    report.RPWETId = "WET";
                    report.RPWETExists = true;
                    report.RPWETCount += 1;
                    report.RPWETOccurrenceIndex = report.RPWETCount;
                    report.RPWETLastOccurrenceIndex = report.RPWETCount;

                    _found = true;

                    #region WineEqualisationTaxManufacturingIndicator
                    _currentXPath.Push("/tns:WineEqualisationTaxManufacturingIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxManufacturingIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG160 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxManufacturingIndicator

                    #region WineEqualisationTaxWholesaleIndicator
                    _currentXPath.Push("/tns:WineEqualisationTaxWholesaleIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxWholesaleIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG161 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxWholesaleIndicator

                    #region WineEqualisationTaxImportingIndicator
                    _currentXPath.Push("/tns:WineEqualisationTaxImportingIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxImportingIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG162 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxImportingIndicator

                    #region WineEqualisationTaxExportingIndicator
                    _currentXPath.Push("/tns:WineEqualisationTaxExportingIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxExportingIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG163 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxExportingIndicator

                    #region WineEqualisationTaxIndirectMarketingRetailerIndicator
                    _currentXPath.Push("/tns:WineEqualisationTaxIndirectMarketingRetailerIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxIndirectMarketingRetailerIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG164 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxIndirectMarketingRetailerIndicator

                    #region WineEqualisationTaxWinePercent
                    _currentXPath.Push("/tns:WineEqualisationTaxWinePercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxWinePercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG165 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxWinePercent

                    #region WineEqualisationTaxBeerPercent
                    _currentXPath.Push("/tns:WineEqualisationTaxBeerPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxBeerPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG166 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxBeerPercent

                    #region WineEqualisationTaxSpiritPercent
                    _currentXPath.Push("/tns:WineEqualisationTaxSpiritPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxSpiritPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG167 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxSpiritPercent

                    #region WineEqualisationTaxOtherPercent
                    _currentXPath.Push("/tns:WineEqualisationTaxOtherPercent");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxOtherPercent")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG168 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxOtherPercent

                    #region WineEqualisationTaxRegistrationStartDate
                    _currentXPath.Push("/tns:WineEqualisationTaxRegistrationStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "WineEqualisationTaxRegistrationStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG169 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion WineEqualisationTaxRegistrationStartDate
                } // End of if WET node exists

                _currentXPath.Pop();
                #endregion WET

                #region PAYGW
                _currentXPath.Push("/tns:PAYGW");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PAYGW")
                {
                    report.RPPAYGWId = "PAYGW";
                    report.RPPAYGWExists = true;
                    report.RPPAYGWCount += 1;
                    report.RPPAYGWOccurrenceIndex = report.RPPAYGWCount;
                    report.RPPAYGWLastOccurrenceIndex = report.RPPAYGWCount;

                    _found = true;

                    #region IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator
                    _currentXPath.Push("/tns:IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG170 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator

                    #region IncomeTaxPayAsYouGoWithholdingRegistrationStartDate
                    _currentXPath.Push("/tns:IncomeTaxPayAsYouGoWithholdingRegistrationStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxPayAsYouGoWithholdingRegistrationStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG171 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IncomeTaxPayAsYouGoWithholdingRegistrationStartDate

                    #region LabourStatisticsEmployeesCount
                    _currentXPath.Push("/tns:LabourStatisticsEmployeesCount");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LabourStatisticsEmployeesCount")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG172 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LabourStatisticsEmployeesCount

                    #region IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount
                    _currentXPath.Push("/tns:IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (Decimal.TryParse(currentValue, out currentDecimalValue))
                                {
                                    report.ABNREG173 = currentDecimalValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount

                    #region LodgmentChannelCode
                    _currentXPath.Push("/tns:LodgmentChannelCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "LodgmentChannelCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG174 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion LodgmentChannelCode

                    #region IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode
                    _currentXPath.Push("/tns:IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG175 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode

                    #region IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator
                    _currentXPath.Push("/tns:IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG176 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator

                    #region EmployerConditionsWorkingHolidayMakerIndicator
                    _currentXPath.Push("/tns:EmployerConditionsWorkingHolidayMakerIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, true) && reader.LocalName == "EmployerConditionsWorkingHolidayMakerIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG230 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion EmployerConditionsWorkingHolidayMakerIndicator
                } // End of if PAYGW node exists

                _currentXPath.Pop();
                #endregion PAYGW

                #region FBT
                _currentXPath.Push("/tns:FBT");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "FBT")
                {
                    report.RPFBTId = "FBT";
                    report.RPFBTExists = true;
                    report.RPFBTCount += 1;
                    report.RPFBTOccurrenceIndex = report.RPFBTCount;
                    report.RPFBTLastOccurrenceIndex = report.RPFBTCount;

                    _found = true;

                    #region OrganisationDetailsOrganisationActivityStatusStartDate
                    _currentXPath.Push("/tns:OrganisationDetailsOrganisationActivityStatusStartDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "OrganisationDetailsOrganisationActivityStatusStartDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG177 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion OrganisationDetailsOrganisationActivityStatusStartDate

                    #region FinancialInstitutionAccountBankStateBranchNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountBankStateBranchNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountBankStateBranchNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG192 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountBankStateBranchNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG196 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNameText
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG194 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNameText
                } // End of if FBT node exists

                _currentXPath.Pop();
                #endregion FBT

                #region TrueAndCorrect
                _currentXPath.Push("/tns:TrueAndCorrect");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "TrueAndCorrect")
                {
                    report.RPTrueAndCorrectId = "TrueAndCorrect";
                    report.RPTrueAndCorrectExists = true;
                    report.RPTrueAndCorrectCount += 1;
                    report.RPTrueAndCorrectOccurrenceIndex = report.RPTrueAndCorrectCount;
                    report.RPTrueAndCorrectLastOccurrenceIndex = report.RPTrueAndCorrectCount;

                    _found = true;

                    #region PersonUnstructuredNameFullNameText
                    _currentXPath.Push("/tns:PersonUnstructuredNameFullNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "PersonUnstructuredNameFullNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG178 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion PersonUnstructuredNameFullNameText

                    #region PersonNameDetailsPositionText
                    _currentXPath.Push("/tns:PersonNameDetailsPositionText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG179 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion PersonNameDetailsPositionText

                    #region ElectronicContactTelephoneAreaCode
                    _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG222 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactTelephoneAreaCode

                    #region ElectronicContactTelephoneMinimalNumber
                    _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG180 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactTelephoneMinimalNumber

                    #region DeclarationSignatureDate
                    _currentXPath.Push("/tns:DeclarationSignatureDate");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationSignatureDate")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                                {
                                    report.ABNREG181 = currentDateTimeValue.Date;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion DeclarationSignatureDate

                    #region DeclarationStatementAcceptedIndicator
                    _currentXPath.Push("/tns:DeclarationStatementAcceptedIndicator");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationStatementAcceptedIndicator")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                currentBooleanValue = ToBoolean(currentValue);
                                if (currentBooleanValue != null)
                                {
                                    report.ABNREG182 = currentBooleanValue;
                                }
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion DeclarationStatementAcceptedIndicator

                    #region DeclarationSignatoryIdentifierText
                    _currentXPath.Push("/tns:DeclarationSignatoryIdentifierText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationSignatoryIdentifierText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG183 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion DeclarationSignatoryIdentifierText
                } // End of if TrueAndCorrect node exists

                _currentXPath.Pop();
                #endregion TrueAndCorrect

                #region Start
                _currentXPath.Push("/tns:Start");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "Start")
                {
                    report.RPStartId = "Start";
                    report.RPStartExists = true;
                    report.RPStartCount += 1;
                    report.RPStartOccurrenceIndex = report.RPStartCount;
                    report.RPStartLastOccurrenceIndex = report.RPStartCount;

                    _found = true;

                    #region InteractionQuestionIdentifier
                    _currentXPath.Push("/tns:InteractionQuestionIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionQuestionIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG10 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion InteractionQuestionIdentifier
                } // End of if Start node exists

                _currentXPath.Pop();
                #endregion Start

                #region Outcome
                _currentXPath.Push("/tns:Outcome");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "Outcome")
                {
                    report.RPOutcomeId = "Outcome";
                    report.RPOutcomeExists = true;
                    report.RPOutcomeCount += 1;
                    report.RPOutcomeOccurrenceIndex = report.RPOutcomeCount;
                    report.RPOutcomeLastOccurrenceIndex = report.RPOutcomeCount;

                    _found = true;

                    #region InteractionOutcomeQuestionIdentifier
                    _currentXPath.Push("/tns:InteractionOutcomeQuestionIdentifier");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "InteractionOutcomeQuestionIdentifier")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG14 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion InteractionOutcomeQuestionIdentifier
                } // End of if Outcome node exists

                _currentXPath.Pop();
                #endregion Outcome

                #region Superannuation
                _currentXPath.Push("/tns:Superannuation");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "Superannuation")
                {
                    report.RPSuperannuationId = "Superannuation";
                    report.RPSuperannuationExists = true;
                    report.RPSuperannuationCount += 1;
                    report.RPSuperannuationOccurrenceIndex = report.RPSuperannuationCount;
                    report.RPSuperannuationLastOccurrenceIndex = report.RPSuperannuationCount;

                    _found = true;

                    #region FinancialInstitutionAccountBankStateBranchNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountBankStateBranchNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountBankStateBranchNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG209 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountBankStateBranchNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG210 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNumber

                    #region FinancialInstitutionAccountFinancialInstitutionAccountNameText
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG211 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountFinancialInstitutionAccountNameText

                    #region ElectronicContactElectronicServiceAddressAliasText
                    _currentXPath.Push("/tns:ElectronicContactElectronicServiceAddressAliasText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactElectronicServiceAddressAliasText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG235 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion ElectronicContactElectronicServiceAddressAliasText
                } // End of if Superannuation node exists

                _currentXPath.Pop();
                #endregion Superannuation

                #region IncomeTaxRefund
                _currentXPath.Push("/tns:IncomeTaxRefund");
                //1. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IncomeTaxRefund")
                {
                    report.RPIncomeTaxRefundId = "IncomeTaxRefund";
                    report.RPIncomeTaxRefundExists = true;
                    report.RPIncomeTaxRefundCount += 1;
                    report.RPIncomeTaxRefundOccurrenceIndex = report.RPIncomeTaxRefundCount;
                    report.RPIncomeTaxRefundLastOccurrenceIndex = report.RPIncomeTaxRefundCount;

                    _found = true;

                    #region BankStateBranchNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountBankStateBranchNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountBankStateBranchNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG231 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion BankStateBranchNumber

                    #region FinancialInstitutionAccountNumber
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNumber");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNumber")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG232 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountNumber

                    #region FinancialInstitutionAccountNameText
                    _currentXPath.Push("/tns:FinancialInstitutionAccountFinancialInstitutionAccountNameText");
                    //6. use case
                    if (ReadToNextElement(reader, false) && reader.LocalName == "FinancialInstitutionAccountFinancialInstitutionAccountNameText")
                    {
                        if (!IsEmptyOrNilElement(reader))
                        {
                            ReadNext(reader);
                            if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                            {
                                currentValue = reader.Value;
                                ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                                report.ABNREG233 = currentValue;
                            }
                        }
                        _found = true;
                    }

                    _currentXPath.Pop();
                    #endregion FinancialInstitutionAccountNameText
                } // End of if IncomeTaxRefund node exists

                _currentXPath.Pop();
                #endregion IncomeTaxRefund
            } // End of if RP node exists

            _currentXPath.Pop();
            #endregion RP

            #region INTTrueAndCorrect
            _currentXPath.Push("/tns:INTTrueAndCorrect");
            //1. use case
            if (ReadToNextElement(reader, false) && reader.LocalName == "INTTrueAndCorrect")
            {
                report.INTTrueAndCorrectId = "INTTrueAndCorrect";
                report.INTTrueAndCorrectExists = true;
                report.INTTrueAndCorrectCount += 1;
                report.INTTrueAndCorrectOccurrenceIndex = report.INTTrueAndCorrectCount;
                report.INTTrueAndCorrectLastOccurrenceIndex = report.INTTrueAndCorrectCount;

                _found = true;

                #region IdentifiersAustralianBusinessNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersAustralianBusinessNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersAustralianBusinessNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG184 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersAustralianBusinessNumberIdentifier

                #region PersonUnstructuredNameFullNameText
                _currentXPath.Push("/tns:PersonUnstructuredNameFullNameText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonUnstructuredNameFullNameText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG185 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonUnstructuredNameFullNameText

                #region PersonNameDetailsPositionText
                _currentXPath.Push("/tns:PersonNameDetailsPositionText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "PersonNameDetailsPositionText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG186 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion PersonNameDetailsPositionText

                #region ElectronicContactTelephoneAreaCode
                _currentXPath.Push("/tns:ElectronicContactTelephoneAreaCode");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneAreaCode")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG223 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactTelephoneAreaCode

                #region ElectronicContactTelephoneMinimalNumber
                _currentXPath.Push("/tns:ElectronicContactTelephoneMinimalNumber");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "ElectronicContactTelephoneMinimalNumber")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG187 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion ElectronicContactTelephoneMinimalNumber

                #region IdentifiersTaxAgentNumberIdentifier
                _currentXPath.Push("/tns:IdentifiersTaxAgentNumberIdentifier");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "IdentifiersTaxAgentNumberIdentifier")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG188 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion IdentifiersTaxAgentNumberIdentifier

                #region DeclarationSignatureDate
                _currentXPath.Push("/tns:DeclarationSignatureDate");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationSignatureDate")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            if (DateTime.TryParse(currentValue, out currentDateTimeValue))
                            {
                                report.ABNREG189 = currentDateTimeValue.Date;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion DeclarationSignatureDate

                #region DeclarationStatementAcceptedIndicator
                _currentXPath.Push("/tns:DeclarationStatementAcceptedIndicator");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationStatementAcceptedIndicator")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            currentBooleanValue = ToBoolean(currentValue);
                            if (currentBooleanValue != null)
                            {
                                report.ABNREG190 = currentBooleanValue;
                            }
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion DeclarationStatementAcceptedIndicator

                #region DeclarationSignatoryIdentifierText
                _currentXPath.Push("/tns:DeclarationSignatoryIdentifierText");
                //6. use case
                if (ReadToNextElement(reader, false) && reader.LocalName == "DeclarationSignatoryIdentifierText")
                {
                    if (!IsEmptyOrNilElement(reader))
                    {
                        ReadNext(reader);
                        if (reader.NodeType == XmlNodeType.Text || reader.NodeType == XmlNodeType.CDATA)
                        {
                            currentValue = reader.Value;
                            ReadNext(reader); // consume the end element so we detect any validation errors before _currentXPath is updated.
                            report.ABNREG191 = currentValue;
                        }
                    }
                    _found = true;
                }

                _currentXPath.Pop();
                #endregion DeclarationSignatoryIdentifierText
            } // End of if INTTrueAndCorrect node exists

            _currentXPath.Pop();
            #endregion INTTrueAndCorrect

            while (reader.EOF != true)
                reader.Read();

            return report;
        }

        //  private string _elementCsvList = "RP#IdentifiersCallReferenceIdentifier,RP#ElectronicContactElectronicServiceAddressText,RP#ElectronicContactDeviceTypeText,RP#SoftwareInformationOperatingSystemText,RP#IdentifiersRequesterReferenceIdentifier,RP#IdentificationDetailsVerificationRequestCount,RP#PartyTypeCode,RP#OrganisationDetailsOrganisationTypeCode,RP#OrganisationDetailsAustralianBusinessRegisterEntityTypeCode,RP#InteractionABNEntitlementIndicator,Entitlement#EntitlementQuestionInteractionQuestionIdentifier,Entitlement#InteractionOptionQuestionIdentifier,Entitlement#EntitlementNextQuestionInteractionQuestionIdentifier,Entitlement,EntitlementCollection,RP#IdentifiersTaxFileNumberInexistentIndicator,RP#IdentifiersAustralianBusinessNumberIdentifier,RP#InteractionABNApplicationIndicator,RP#InteractionTFNApplicationIndicator,RP#PartyGovernmentTierCode,RP#OrganisationDetailsNotForProfitIndicator,RP#IncomeTaxExemptionIndicator,RP#IdentifiersTaxAgentNumberIdentifier,RP#SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount,RP#SuperannuationFundDetailsFundTypeCode,RP#SuperannuationFundDetailsFundBenefitStructureCode,RP#ResidencyTaxPurposesPersonStatusIndicator,RP#IdentifiersAustralianCompanyNumberIdentifier,RP#IdentifiersAustralianRegisteredBodyNumberIdentifier,RP#OrganisationNameDetailsOrganisationalNameText,RP#PersonDemographicDetailsBirthDate,RP#PersonNameDetailsFamilyNameText,RP#PersonNameDetailsGivenNameText,RP#PersonNameDetailsOtherGivenNameText,RP#PersonNameDetailsTitleText,RP#PersonDemographicDetailsSexCode,RP#IdentifiersTaxFileNumberIdentifier,RP#OrganisationDetailsAgricultureActivityIndicator,RP#OrganisationDetailsGovernmentControlledOwnedIndicator,RP#OrganisationDetailsMainIncomeActivityDescription,RP#OrganisationDetailsMainIncomeActivityCode,RP#OrganisationDetailsOrganisationActivityStatusEndDate,RP#OrganisationDetailsOrganisationActivityStatusStartDate,RP#OrganisationDetailsMultipleBusinessLocationIndicator,RP#ElectronicContactTelephoneServiceLineCode,RP#ElectronicContactTelephoneAreaCode,RP#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation#OrganisationDetailsMainBusinessActivityIndicator,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityDescription,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityCode,AdditionalBusinessLocation#AddressDetailsLine1Text,AdditionalBusinessLocation#AddressDetailsLine2Text,AdditionalBusinessLocation#AddressDetailsCountryCode,AdditionalBusinessLocation#AddressDetailsPostcodeText,AdditionalBusinessLocation#AddressDetailsStateOrTerritoryCode,AdditionalBusinessLocation#AddressDetailsLocalityNameText,AdditionalBusinessLocation#ElectronicContactElectronicMailAddressText,AdditionalBusinessLocation#ElectronicContactTelephoneServiceLineCode,AdditionalBusinessLocation#ElectronicContactTelephoneAreaCode,AdditionalBusinessLocation#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation,AdditionalBusinessLocationCollection,AuthorisedContact#PersonNameDetailsTitleText,AuthorisedContact#PersonNameDetailsGivenNameText,AuthorisedContact#PersonNameDetailsFamilyNameText,AuthorisedContact#ElectronicContactTelephoneAreaCode,AuthorisedContact#ElectronicContactTelephoneMinimalNumber,AfterhoursContactTelephone,AuthorisedContact#ElectronicContactTelephoneAreaCode,AuthorisedContact#ElectronicContactTelephoneMinimalNumber,BusinessHoursContactTelephone,AuthorisedContact#ElectronicContactElectronicMailAddressText,AuthorisedContact#ElectronicContactFacsimileAreaCode,AuthorisedContact#ElectronicContactFacsimileMinimalNumber,AuthorisedContact#ElectronicContactTelephoneMobileNumber,AuthorisedContact#PersonDemographicDetailsLanguagePreferredCode,AuthorisedContact#PersonDemographicDetailsLanguagePreferredOtherDescription,AuthorisedContact#PersonNameDetailsPositionText,AuthorisedContact,AuthorisedContactCollection,AssociateIndividual#PersonDemographicDetailsBirthDate,AssociateIndividual#PersonNameDetailsFamilyNameText,AssociateIndividual#PersonNameDetailsGivenNameText,AssociateIndividual#PersonNameDetailsOtherGivenNameText,AssociateIndividual#PersonNameDetailsTitleText,AssociateIndividual#PersonDemographicDetailsSexCode,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateIndividual#IdentifiersTaxFileNumberIdentifier,AssociateIndividual#AddressDetailsLine1Text,AssociateIndividual#AddressDetailsLine2Text,AssociateIndividual#AddressDetailsLocalityNameText,AssociateIndividual#AddressDetailsPostcodeText,AssociateIndividual#AddressDetailsStateOrTerritoryCode,AssociateIndividual#AddressDetailsCountryCode,AssociateIndividual,AssociateIndividualCollection,AssociateOrganisation#IdentifiersAustralianCompanyNumberIdentifier,AssociateOrganisation#IdentifiersAustralianRegisteredBodyNumberIdentifier,AssociateOrganisation#OrganisationNameDetailsOrganisationalNameText,AssociateOrganisation#IdentifiersAustralianBusinessNumberIdentifier,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateOrganisation#IdentifiersTaxFileNumberIdentifier,AssociateOrganisation#PeriodStartDate,AssociateOrganisation#AddressDetailsLine1Text,AssociateOrganisation#AddressDetailsLine2Text,AssociateOrganisation#AddressDetailsLocalityNameText,AssociateOrganisation#AddressDetailsPostcodeText,AssociateOrganisation#AddressDetailsStateOrTerritoryCode,AssociateOrganisation#AddressDetailsCountryCode,AssociateOrganisation,AssociateOrganisationCollection,RP#OrganisationDetailsRegisteredLegalEntityIndicator,RP#InteractionABNApplicationReasonCode,RP#PersonDemographicDetailsFirstTimeDirectorIndicator,RP#PersonDemographicDetailsFirstTimeContractorIndicator,RP#PersonDemographicDetailsFirstTimeSelfEmployedIndicator,RP#PersonDemographicDetailsGoverningRulesIndicator,RP#SuperannuationRegulatoryInformationElectionDate,RP#SuperannuationFundDetailsAgePensionFundIndicator,RP#OrganisationDetailsLiquidatorAppointedIndicator,RP#OrganisationDetailsDisqualifiedOfficerIndicator,RP#OrganisationDetailsReceiverAppointedIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator,RP#OrganisationDetailsCivilPenaltyOrderIndicator,RP#OrganisationDetailsConvictionIndicator,RP#SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator,RP#OrganisationDetailsOperationCeaseIndicator,RP#OrganisationControlCompanyOfficialManagementIndicator,UltimateHoldingCompany#IdentifiersAustralianCompanyNumberIdentifier,UltimateHoldingCompany#IdentifiersAustralianRegisteredBodyNumberIdentifier,UltimateHoldingCompany,AddressDetailsBusiness#OrganisationDetailsMainBusinessActivityIndicator,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityDescription,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityCode,AddressDetailsBusiness#Line1Text,AddressDetailsBusiness#Line2Text,AddressDetailsBusiness#CountryCode,AddressDetailsBusiness#PostcodeText,AddressDetailsBusiness#StateOrTerritoryCode,AddressDetailsBusiness#LocalityNameText,AddressDetailsBusiness,Correspondence#AddressText,Correspondence,ElectronicContactElectronicMailBusiness#AddressText,ElectronicContactElectronicMailBusiness,AddressDetailsPostal#Line1Text,AddressDetailsPostal#Line2Text,AddressDetailsPostal#CountryCode,AddressDetailsPostal#PostcodeText,AddressDetailsPostal#StateOrTerritoryCode,AddressDetailsPostal#LocalityNameText,AddressDetailsPostal,AUSkey#InteractionAUSKeyApplicationIndicator,AUSkey#ElectronicContactElectronicMailAddressText,AUSkey#ElectronicContactTelephoneCountryCode,AUSkey#ElectronicContactTelephoneAreaCode,AUSkey#ElectronicContactTelephoneMinimalNumber,AUSkey,Previous#IdentifiersAustralianBusinessNumberIdentifier,Previous,BusinessPrev#IdentifiersAustralianBusinessNumberIdentifier,BusinessPrev,GST#GoodsAndServicesTaxRegistrationReasonCode,GST#GoodsAndServicesTaxRegistrationStartDate,GST#GoodsAndServicesTaxTurnoverRangeCode,GST#LodgmentFrequencyCode,GST#AccountingPoliciesCashAccountingMethodUsedIndicator,GST#GoodsAndServicesTaxImportIndicator,GST#FinancialInstitutionAccountBankStateBranchNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNameText,GST#FinancialInstitutionAccountHolderTypeCode,GST,FTC#FuelTaxRegistrationStartDate,FuelTaxFuelTypeCode,FuelTaxFuelTypeCodeCollection,FTC#FuelTaxHeavyVehicleIndicator,FTC,LCT#LuxuryCarTaxRegistrationRequiredIndicator,LCT#LuxuryCarTaxActivityCode,LCT#LuxuryCarTaxLiabilityRangeCode,LCT#LuxuryCarTaxRegistrationStartDate,LCT#LuxuryCarTaxManufacturingPercent,LCT#LuxuryCarTaxWholesalePercent,LCT#LuxuryCarTaxImportingPercent,LCT#LuxuryCarTaxRetailingPercent,LCT#LuxuryCarTaxActivityStatementRegistrationIndicator,LCT,WET#WineEqualisationTaxManufacturingIndicator,WET#WineEqualisationTaxWholesaleIndicator,WET#WineEqualisationTaxImportingIndicator,WET#WineEqualisationTaxExportingIndicator,WET#WineEqualisationTaxIndirectMarketingRetailerIndicator,WET#WineEqualisationTaxWinePercent,WET#WineEqualisationTaxBeerPercent,WET#WineEqualisationTaxSpiritPercent,WET#WineEqualisationTaxOtherPercent,WET#WineEqualisationTaxRegistrationStartDate,WET,PAYGW#IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator,PAYGW#IncomeTaxPayAsYouGoWithholdingRegistrationStartDate,PAYGW#LabourStatisticsEmployeesCount,PAYGW#IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount,PAYGW#LodgmentChannelCode,PAYGW#IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode,PAYGW#IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator,PAYGW#EmployerConditionsWorkingHolidayMakerIndicator,PAYGW,FBT#OrganisationDetailsOrganisationActivityStatusStartDate,FBT#FinancialInstitutionAccountBankStateBranchNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNameText,FBT,TrueAndCorrect#PersonUnstructuredNameFullNameText,TrueAndCorrect#PersonNameDetailsPositionText,TrueAndCorrect#ElectronicContactTelephoneAreaCode,TrueAndCorrect#ElectronicContactTelephoneMinimalNumber,TrueAndCorrect#DeclarationSignatureDate,TrueAndCorrect#DeclarationStatementAcceptedIndicator,TrueAndCorrect#DeclarationSignatoryIdentifierText,TrueAndCorrect,Start#InteractionQuestionIdentifier,Start,Outcome#InteractionOutcomeQuestionIdentifier,Outcome,Superannuation#FinancialInstitutionAccountBankStateBranchNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNameText,Superannuation#ElectronicContactElectronicServiceAddressAliasText,Superannuation,IncomeTaxRefund#BankStateBranchNumber,IncomeTaxRefund#FinancialInstitutionAccountNumber,IncomeTaxRefund#FinancialInstitutionAccountNameText,IncomeTaxRefund,RP,INTTrueAndCorrect#IdentifiersAustralianBusinessNumberIdentifier,INTTrueAndCorrect#PersonUnstructuredNameFullNameText,INTTrueAndCorrect#PersonNameDetailsPositionText,INTTrueAndCorrect#ElectronicContactTelephoneAreaCode,INTTrueAndCorrect#ElectronicContactTelephoneMinimalNumber,INTTrueAndCorrect#IdentifiersTaxAgentNumberIdentifier,INTTrueAndCorrect#DeclarationSignatureDate,INTTrueAndCorrect#DeclarationStatementAcceptedIndicator,INTTrueAndCorrect#DeclarationSignatoryIdentifierText,INTTrueAndCorrect";
        //  private string _elementCsvList = "RP#IdentifiersCallReferenceIdentifier,RP#ElectronicContactElectronicServiceAddressText,RP#ElectronicContactDeviceTypeText,RP#SoftwareInformationOperatingSystemText,RP#IdentifiersRequesterReferenceIdentifier,RP#IdentificationDetailsVerificationRequestCount,RP#PartyTypeCode,RP#OrganisationDetailsOrganisationTypeCode,RP#OrganisationDetailsAustralianBusinessRegisterEntityTypeCode,RP#InteractionABNEntitlementIndicator,Entitlement#EntitlementQuestionInteractionQuestionIdentifier,Entitlement#InteractionOptionQuestionIdentifier,Entitlement#EntitlementNextQuestionInteractionQuestionIdentifier,Entitlement,EntitlementCollection,RP#IdentifiersTaxFileNumberInexistentIndicator,RP#IdentifiersAustralianBusinessNumberIdentifier,RP#InteractionABNApplicationIndicator,RP#InteractionTFNApplicationIndicator,RP#PartyGovernmentTierCode,RP#OrganisationDetailsNotForProfitIndicator,RP#IncomeTaxExemptionIndicator,RP#IdentifiersTaxAgentNumberIdentifier,RP#SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount,RP#SuperannuationFundDetailsFundTypeCode,RP#SuperannuationFundDetailsFundBenefitStructureCode,RP#ResidencyTaxPurposesPersonStatusIndicator,RP#IdentifiersAustralianCompanyNumberIdentifier,RP#IdentifiersAustralianRegisteredBodyNumberIdentifier,RP#OrganisationNameDetailsOrganisationalNameText,RP#PersonDemographicDetailsBirthDate,RP#PersonNameDetailsFamilyNameText,RP#PersonNameDetailsGivenNameText,RP#PersonNameDetailsOtherGivenNameText,RP#PersonNameDetailsTitleText,RP#PersonDemographicDetailsSexCode,RP#IdentifiersTaxFileNumberIdentifier,RP#OrganisationDetailsAgricultureActivityIndicator,RP#OrganisationDetailsGovernmentControlledOwnedIndicator,RP#OrganisationDetailsMainIncomeActivityDescription,RP#OrganisationDetailsMainIncomeActivityCode,RP#OrganisationDetailsOrganisationActivityStatusEndDate,RP#OrganisationDetailsOrganisationActivityStatusStartDate,RP#OrganisationDetailsMultipleBusinessLocationIndicator,RP#ElectronicContactTelephoneServiceLineCode,RP#ElectronicContactTelephoneAreaCode,RP#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation#OrganisationDetailsMainBusinessActivityIndicator,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityDescription,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityCode,AdditionalBusinessLocation#AddressDetailsLine1Text,AdditionalBusinessLocation#AddressDetailsLine2Text,AdditionalBusinessLocation#AddressDetailsCountryCode,AdditionalBusinessLocation#AddressDetailsPostcodeText,AdditionalBusinessLocation#AddressDetailsStateOrTerritoryCode,AdditionalBusinessLocation#AddressDetailsLocalityNameText,AdditionalBusinessLocation#ElectronicContactElectronicMailAddressText,AdditionalBusinessLocation#ElectronicContactTelephoneServiceLineCode,AdditionalBusinessLocation#ElectronicContactTelephoneAreaCode,AdditionalBusinessLocation#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation,AdditionalBusinessLocationCollection,AuthorisedContact#PersonNameDetailsTitleText,AuthorisedContact#PersonNameDetailsGivenNameText,AuthorisedContact#PersonNameDetailsFamilyNameText,AuthorisedContact#ElectronicContactTelephoneAreaCode,AuthorisedContact#ElectronicContactTelephoneMinimalNumber,AfterhoursContactTelephone,AuthorisedContact#ElectronicContactTelephoneAreaCode,AuthorisedContact#ElectronicContactTelephoneMinimalNumber,BusinessHoursContactTelephone,AuthorisedContact#ElectronicContactElectronicMailAddressText,AuthorisedContact#ElectronicContactFacsimileAreaCode,AuthorisedContact#ElectronicContactFacsimileMinimalNumber,AuthorisedContact#ElectronicContactTelephoneMobileNumber,AuthorisedContact#PersonDemographicDetailsLanguagePreferredCode,AuthorisedContact#PersonDemographicDetailsLanguagePreferredOtherDescription,AuthorisedContact#PersonNameDetailsPositionText,AuthorisedContact,AuthorisedContactCollection,AssociateIndividual#PersonDemographicDetailsBirthDate,AssociateIndividual#PersonNameDetailsFamilyNameText,AssociateIndividual#PersonNameDetailsGivenNameText,AssociateIndividual#PersonNameDetailsOtherGivenNameText,AssociateIndividual#PersonNameDetailsTitleText,AssociateIndividual#PersonDemographicDetailsSexCode,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateIndividual#IdentifiersTaxFileNumberIdentifier,AssociateIndividual#AddressDetailsLine1Text,AssociateIndividual#AddressDetailsLine2Text,AssociateIndividual#AddressDetailsLocalityNameText,AssociateIndividual#AddressDetailsPostcodeText,AssociateIndividual#AddressDetailsStateOrTerritoryCode,AssociateIndividual#AddressDetailsCountryCode,AssociateIndividual,AssociateIndividualCollection,AssociateOrganisation#IdentifiersAustralianCompanyNumberIdentifier,AssociateOrganisation#IdentifiersAustralianRegisteredBodyNumberIdentifier,AssociateOrganisation#OrganisationNameDetailsOrganisationalNameText,AssociateOrganisation#IdentifiersAustralianBusinessNumberIdentifier,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateOrganisation#IdentifiersTaxFileNumberIdentifier,AssociateOrganisation#PeriodStartDate,AssociateOrganisation#AddressDetailsLine1Text,AssociateOrganisation#AddressDetailsLine2Text,AssociateOrganisation#AddressDetailsLocalityNameText,AssociateOrganisation#AddressDetailsPostcodeText,AssociateOrganisation#AddressDetailsStateOrTerritoryCode,AssociateOrganisation#AddressDetailsCountryCode,AssociateOrganisation,AssociateOrganisationCollection,RP#OrganisationDetailsRegisteredLegalEntityIndicator,RP#InteractionABNApplicationReasonCode,RP#PersonDemographicDetailsFirstTimeDirectorIndicator,RP#PersonDemographicDetailsFirstTimeContractorIndicator,RP#PersonDemographicDetailsFirstTimeSelfEmployedIndicator,RP#PersonDemographicDetailsGoverningRulesIndicator,RP#SuperannuationRegulatoryInformationElectionDate,RP#SuperannuationFundDetailsAgePensionFundIndicator,RP#OrganisationDetailsLiquidatorAppointedIndicator,RP#OrganisationDetailsDisqualifiedOfficerIndicator,RP#OrganisationDetailsReceiverAppointedIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator,RP#OrganisationDetailsCivilPenaltyOrderIndicator,RP#OrganisationDetailsConvictionIndicator,RP#SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator,RP#OrganisationDetailsOperationCeaseIndicator,RP#OrganisationControlCompanyOfficialManagementIndicator,UltimateHoldingCompany#IdentifiersAustralianCompanyNumberIdentifier,UltimateHoldingCompany#IdentifiersAustralianRegisteredBodyNumberIdentifier,UltimateHoldingCompany,AddressDetailsBusiness#OrganisationDetailsMainBusinessActivityIndicator,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityDescription,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityCode,AddressDetailsBusiness#Line1Text,AddressDetailsBusiness#Line2Text,AddressDetailsBusiness#CountryCode,AddressDetailsBusiness#PostcodeText,AddressDetailsBusiness#StateOrTerritoryCode,AddressDetailsBusiness#LocalityNameText,AddressDetailsBusiness,Correspondence#AddressText,Correspondence,ElectronicContactElectronicMailBusiness#AddressText,ElectronicContactElectronicMailBusiness,AddressDetailsPostal#Line1Text,AddressDetailsPostal#Line2Text,AddressDetailsPostal#CountryCode,AddressDetailsPostal#PostcodeText,AddressDetailsPostal#StateOrTerritoryCode,AddressDetailsPostal#LocalityNameText,AddressDetailsPostal,AUSkey#InteractionAUSKeyApplicationIndicator,AUSkey#ElectronicContactElectronicMailAddressText,AUSkey#ElectronicContactTelephoneCountryCode,AUSkey#ElectronicContactTelephoneAreaCode,AUSkey#ElectronicContactTelephoneMinimalNumber,AUSkey,Previous#IdentifiersAustralianBusinessNumberIdentifier,Previous,BusinessPrev#IdentifiersAustralianBusinessNumberIdentifier,BusinessPrev,GST#GoodsAndServicesTaxRegistrationReasonCode,GST#GoodsAndServicesTaxRegistrationStartDate,GST#GoodsAndServicesTaxTurnoverRangeCode,GST#LodgmentFrequencyCode,GST#AccountingPoliciesCashAccountingMethodUsedIndicator,GST#GoodsAndServicesTaxImportIndicator,GST#FinancialInstitutionAccountBankStateBranchNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNameText,GST#FinancialInstitutionAccountHolderTypeCode,GST,FTC#FuelTaxRegistrationStartDate,FuelTaxFuelTypeCode,FuelTaxFuelTypeCodeCollection,FTC#FuelTaxHeavyVehicleIndicator,FTC,LCT#LuxuryCarTaxRegistrationRequiredIndicator,LCT#LuxuryCarTaxActivityCode,LCT#LuxuryCarTaxLiabilityRangeCode,LCT#LuxuryCarTaxRegistrationStartDate,LCT#LuxuryCarTaxManufacturingPercent,LCT#LuxuryCarTaxWholesalePercent,LCT#LuxuryCarTaxImportingPercent,LCT#LuxuryCarTaxRetailingPercent,LCT#LuxuryCarTaxActivityStatementRegistrationIndicator,LCT,WET#WineEqualisationTaxManufacturingIndicator,WET#WineEqualisationTaxWholesaleIndicator,WET#WineEqualisationTaxImportingIndicator,WET#WineEqualisationTaxExportingIndicator,WET#WineEqualisationTaxIndirectMarketingRetailerIndicator,WET#WineEqualisationTaxWinePercent,WET#WineEqualisationTaxBeerPercent,WET#WineEqualisationTaxSpiritPercent,WET#WineEqualisationTaxOtherPercent,WET#WineEqualisationTaxRegistrationStartDate,WET,PAYGW#IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator,PAYGW#IncomeTaxPayAsYouGoWithholdingRegistrationStartDate,PAYGW#LabourStatisticsEmployeesCount,PAYGW#IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount,PAYGW#LodgmentChannelCode,PAYGW#IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode,PAYGW#IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator,PAYGW#EmployerConditionsWorkingHolidayMakerIndicator,PAYGW,FBT#OrganisationDetailsOrganisationActivityStatusStartDate,FBT#FinancialInstitutionAccountBankStateBranchNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNameText,FBT,TrueAndCorrect#PersonUnstructuredNameFullNameText,TrueAndCorrect#PersonNameDetailsPositionText,TrueAndCorrect#ElectronicContactTelephoneAreaCode,TrueAndCorrect#ElectronicContactTelephoneMinimalNumber,TrueAndCorrect#DeclarationSignatureDate,TrueAndCorrect#DeclarationStatementAcceptedIndicator,TrueAndCorrect#DeclarationSignatoryIdentifierText,TrueAndCorrect,Start#InteractionQuestionIdentifier,Start,Outcome#InteractionOutcomeQuestionIdentifier,Outcome,Superannuation#FinancialInstitutionAccountBankStateBranchNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNameText,Superannuation#ElectronicContactElectronicServiceAddressAliasText,Superannuation,IncomeTaxRefund#FinancialInstitutionAccountBankStateBranchNumber,IncomeTaxRefund#FinancialInstitutionAccountFinancialInstitutionAccountNumber,IncomeTaxRefund#FinancialInstitutionAccountFinancialInstitutionAccountNameText,IncomeTaxRefund,RP,INTTrueAndCorrect#IdentifiersAustralianBusinessNumberIdentifier,INTTrueAndCorrect#PersonUnstructuredNameFullNameText,INTTrueAndCorrect#PersonNameDetailsPositionText,INTTrueAndCorrect#ElectronicContactTelephoneAreaCode,INTTrueAndCorrect#ElectronicContactTelephoneMinimalNumber,INTTrueAndCorrect#IdentifiersTaxAgentNumberIdentifier,INTTrueAndCorrect#DeclarationSignatureDate,INTTrueAndCorrect#DeclarationStatementAcceptedIndicator,INTTrueAndCorrect#DeclarationSignatoryIdentifierText,INTTrueAndCorrect";
        private string _elementCsvList = "RP#IdentifiersCallReferenceIdentifier,RP#ElectronicContactElectronicServiceAddressText,RP#ElectronicContactDeviceTypeText,RP#SoftwareInformationOperatingSystemText,RP#IdentifiersRequesterReferenceIdentifier,RP#IdentificationDetailsVerificationRequestCount,RP#PartyTypeCode,RP#OrganisationDetailsOrganisationTypeCode,RP#OrganisationDetailsAustralianBusinessRegisterEntityTypeCode,RP#InteractionABNEntitlementIndicator,Entitlement#EntitlementQuestionInteractionQuestionIdentifier,Entitlement#InteractionOptionQuestionIdentifier,Entitlement#EntitlementNextQuestionInteractionQuestionIdentifier,Entitlement,EntitlementCollection,RP#IdentifiersTaxFileNumberInexistentIndicator,RP#IdentifiersAustralianBusinessNumberIdentifier,RP#InteractionABNApplicationIndicator,RP#InteractionTFNApplicationIndicator,RP#PartyGovernmentTierCode,RP#OrganisationDetailsNotForProfitIndicator,RP#IncomeTaxExemptionIndicator,RP#IdentifiersTaxAgentNumberIdentifier,RP#SuperannuationFundDetailsDefinedBenefitRegisteredMemberAccountCount,RP#SuperannuationFundDetailsFundTypeCode,RP#SuperannuationFundDetailsFundBenefitStructureCode,RP#ResidencyTaxPurposesPersonStatusIndicator,RP#IdentifiersAustralianCompanyNumberIdentifier,RP#IdentifiersAustralianRegisteredBodyNumberIdentifier,RP#OrganisationNameDetailsOrganisationalNameText,RP#PersonDemographicDetailsBirthDate,RP#PersonNameDetailsFamilyNameText,RP#PersonNameDetailsGivenNameText,RP#PersonNameDetailsOtherGivenNameText,RP#PersonNameDetailsTitleText,RP#PersonDemographicDetailsSexCode,RP#IdentifiersTaxFileNumberIdentifier,RP#OrganisationDetailsAgricultureActivityIndicator,RP#OrganisationDetailsGovernmentControlledOwnedIndicator,RP#OrganisationDetailsMainIncomeActivityDescription,RP#OrganisationDetailsMainIncomeActivityCode,RP#OrganisationDetailsOrganisationActivityStatusEndDate,RP#OrganisationDetailsOrganisationActivityStatusStartDate,RP#OrganisationDetailsMultipleBusinessLocationIndicator,RP#ElectronicContactTelephoneServiceLineCode,RP#ElectronicContactTelephoneAreaCode,RP#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation#OrganisationDetailsMainBusinessActivityIndicator,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityDescription,AdditionalBusinessLocation#OrganisationDetailsMainIncomeActivityCode,AdditionalBusinessLocation#AddressDetailsLine1Text,AdditionalBusinessLocation#AddressDetailsLine2Text,AdditionalBusinessLocation#AddressDetailsCountryCode,AdditionalBusinessLocation#AddressDetailsPostcodeText,AdditionalBusinessLocation#AddressDetailsStateOrTerritoryCode,AdditionalBusinessLocation#AddressDetailsLocalityNameText,AdditionalBusinessLocation#ElectronicContactElectronicMailAddressText,AdditionalBusinessLocation#ElectronicContactTelephoneServiceLineCode,AdditionalBusinessLocation#ElectronicContactTelephoneAreaCode,AdditionalBusinessLocation#ElectronicContactTelephoneMinimalNumber,AdditionalBusinessLocation,AdditionalBusinessLocationCollection,AuthorisedContact#PersonNameDetailsTitleText,AuthorisedContact#PersonNameDetailsGivenNameText,AuthorisedContact#PersonNameDetailsFamilyNameText,AuthorisedContact#AfterhoursContactTelephone,ElectronicContactTelephoneAreaCode,AuthorisedContact#AfterhoursContactTelephone,ElectronicContactTelephoneMinimalNumber,AuthorisedContact#ElectronicContactTelephoneAreaCode,AuthorisedContact#ElectronicContactTelephoneMinimalNumber,BusinessHoursContactTelephone,AuthorisedContact#ElectronicContactElectronicMailAddressText,AuthorisedContact#ElectronicContactFacsimileAreaCode,AuthorisedContact#ElectronicContactFacsimileMinimalNumber,AuthorisedContact#ElectronicContactTelephoneMobileNumber,AuthorisedContact#PersonDemographicDetailsLanguagePreferredCode,AuthorisedContact#PersonDemographicDetailsLanguagePreferredOtherDescription,AuthorisedContact#PersonNameDetailsPositionText,AuthorisedContact,AuthorisedContactCollection,AssociateIndividual#PersonDemographicDetailsBirthDate,AssociateIndividual#PersonNameDetailsFamilyNameText,AssociateIndividual#PersonNameDetailsGivenNameText,AssociateIndividual#PersonNameDetailsOtherGivenNameText,AssociateIndividual#PersonNameDetailsTitleText,AssociateIndividual#PersonDemographicDetailsSexCode,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateIndividual#IdentifiersTaxFileNumberIdentifier,AssociateIndividual#AddressDetailsLine1Text,AssociateIndividual#AddressDetailsLine2Text,AssociateIndividual#AddressDetailsLocalityNameText,AssociateIndividual#AddressDetailsPostcodeText,AssociateIndividual#AddressDetailsStateOrTerritoryCode,AssociateIndividual#AddressDetailsCountryCode,AssociateIndividual,AssociateIndividualCollection,AssociateOrganisation#IdentifiersAustralianCompanyNumberIdentifier,AssociateOrganisation#IdentifiersAustralianRegisteredBodyNumberIdentifier,AssociateOrganisation#OrganisationNameDetailsOrganisationalNameText,AssociateOrganisation#IdentifiersAustralianBusinessNumberIdentifier,PersonNameDetailsPositionText,PersonNameDetailsPositionTextCollection,AssociateOrganisation#IdentifiersTaxFileNumberIdentifier,AssociateOrganisation#PeriodStartDate,AssociateOrganisation#AddressDetailsLine1Text,AssociateOrganisation#AddressDetailsLine2Text,AssociateOrganisation#AddressDetailsLocalityNameText,AssociateOrganisation#AddressDetailsPostcodeText,AssociateOrganisation#AddressDetailsStateOrTerritoryCode,AssociateOrganisation#AddressDetailsCountryCode,AssociateOrganisation,AssociateOrganisationCollection,RP#OrganisationDetailsRegisteredLegalEntityIndicator,RP#InteractionABNApplicationReasonCode,RP#PersonDemographicDetailsFirstTimeDirectorIndicator,RP#PersonDemographicDetailsFirstTimeContractorIndicator,RP#PersonDemographicDetailsFirstTimeSelfEmployedIndicator,RP#PersonDemographicDetailsGoverningRulesIndicator,RP#SuperannuationRegulatoryInformationElectionDate,RP#SuperannuationFundDetailsAgePensionFundIndicator,RP#OrganisationDetailsLiquidatorAppointedIndicator,RP#OrganisationDetailsDisqualifiedOfficerIndicator,RP#OrganisationDetailsReceiverAppointedIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundActivityIndicator,RP#SuperannuationFundDetailsSelfManagedSuperannuationFundTrusteesBankruptIndicator,RP#OrganisationDetailsCivilPenaltyOrderIndicator,RP#OrganisationDetailsConvictionIndicator,RP#SuperannuationRegulatoryInformationDisqualifiedTrusteesOrDirectorsIndicator,RP#OrganisationDetailsOperationCeaseIndicator,RP#OrganisationControlCompanyOfficialManagementIndicator,UltimateHoldingCompany#IdentifiersAustralianCompanyNumberIdentifier,UltimateHoldingCompany#IdentifiersAustralianRegisteredBodyNumberIdentifier,UltimateHoldingCompany,AddressDetailsBusiness#OrganisationDetailsMainBusinessActivityIndicator,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityDescription,AddressDetailsBusiness#OrganisationDetailsMainIncomeActivityCode,AddressDetailsBusiness#Line1Text,AddressDetailsBusiness#Line2Text,AddressDetailsBusiness#CountryCode,AddressDetailsBusiness#PostcodeText,AddressDetailsBusiness#StateOrTerritoryCode,AddressDetailsBusiness#LocalityNameText,AddressDetailsBusiness,Correspondence#AddressText,Correspondence,ElectronicContactElectronicMailBusiness#AddressText,ElectronicContactElectronicMailBusiness,AddressDetailsPostal#Line1Text,AddressDetailsPostal#Line2Text,AddressDetailsPostal#CountryCode,AddressDetailsPostal#PostcodeText,AddressDetailsPostal#StateOrTerritoryCode,AddressDetailsPostal#LocalityNameText,AddressDetailsPostal,AUSkey#InteractionAUSKeyApplicationIndicator,AUSkey#ElectronicContactElectronicMailAddressText,AUSkey#ElectronicContactTelephoneCountryCode,AUSkey#ElectronicContactTelephoneAreaCode,AUSkey#ElectronicContactTelephoneMinimalNumber,AUSkey,Previous#IdentifiersAustralianBusinessNumberIdentifier,Previous,BusinessPrev#IdentifiersAustralianBusinessNumberIdentifier,BusinessPrev,GST#GoodsAndServicesTaxRegistrationReasonCode,GST#GoodsAndServicesTaxRegistrationStartDate,GST#GoodsAndServicesTaxTurnoverRangeCode,GST#LodgmentFrequencyCode,GST#AccountingPoliciesCashAccountingMethodUsedIndicator,GST#GoodsAndServicesTaxImportIndicator,GST#FinancialInstitutionAccountBankStateBranchNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNumber,GST#FinancialInstitutionAccountFinancialInstitutionAccountNameText,GST#FinancialInstitutionAccountHolderTypeCode,GST,FTC#FuelTaxRegistrationStartDate,FuelTaxFuelTypeCode,FuelTaxFuelTypeCodeCollection,FTC#FuelTaxHeavyVehicleIndicator,FTC,LCT#LuxuryCarTaxRegistrationRequiredIndicator,LCT#LuxuryCarTaxActivityCode,LCT#LuxuryCarTaxLiabilityRangeCode,LCT#LuxuryCarTaxRegistrationStartDate,LCT#LuxuryCarTaxManufacturingPercent,LCT#LuxuryCarTaxWholesalePercent,LCT#LuxuryCarTaxImportingPercent,LCT#LuxuryCarTaxRetailingPercent,LCT#LuxuryCarTaxActivityStatementRegistrationIndicator,LCT,WET#WineEqualisationTaxManufacturingIndicator,WET#WineEqualisationTaxWholesaleIndicator,WET#WineEqualisationTaxImportingIndicator,WET#WineEqualisationTaxExportingIndicator,WET#WineEqualisationTaxIndirectMarketingRetailerIndicator,WET#WineEqualisationTaxWinePercent,WET#WineEqualisationTaxBeerPercent,WET#WineEqualisationTaxSpiritPercent,WET#WineEqualisationTaxOtherPercent,WET#WineEqualisationTaxRegistrationStartDate,WET,PAYGW#IncomeTaxPayAsYouGoWithholdingLegislationRequirementIndicator,PAYGW#IncomeTaxPayAsYouGoWithholdingRegistrationStartDate,PAYGW#LabourStatisticsEmployeesCount,PAYGW#IncomeTaxPayAsYouGoWithholdingEstimatedTaxWithheldAmount,PAYGW#LodgmentChannelCode,PAYGW#IncomeTaxPayAsYouGoWithholdingPaymentSummaryProvisionMethodCode,PAYGW#IncomeTaxPayAsYouGoWithholdingInvestmentBodyIndicator,PAYGW#EmployerConditionsWorkingHolidayMakerIndicator,PAYGW,FBT#OrganisationDetailsOrganisationActivityStatusStartDate,FBT#FinancialInstitutionAccountBankStateBranchNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNumber,FBT#FinancialInstitutionAccountFinancialInstitutionAccountNameText,FBT,TrueAndCorrect#PersonUnstructuredNameFullNameText,TrueAndCorrect#PersonNameDetailsPositionText,TrueAndCorrect#ElectronicContactTelephoneAreaCode,TrueAndCorrect#ElectronicContactTelephoneMinimalNumber,TrueAndCorrect#DeclarationSignatureDate,TrueAndCorrect#DeclarationStatementAcceptedIndicator,TrueAndCorrect#DeclarationSignatoryIdentifierText,TrueAndCorrect,Start#InteractionQuestionIdentifier,Start,Outcome#InteractionOutcomeQuestionIdentifier,Outcome,Superannuation#FinancialInstitutionAccountBankStateBranchNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNumber,Superannuation#FinancialInstitutionAccountFinancialInstitutionAccountNameText,Superannuation#ElectronicContactElectronicServiceAddressAliasText,Superannuation,IncomeTaxRefund#FinancialInstitutionAccountBankStateBranchNumber,IncomeTaxRefund#FinancialInstitutionAccountFinancialInstitutionAccountNumber,IncomeTaxRefund#FinancialInstitutionAccountFinancialInstitutionAccountNameText,IncomeTaxRefund,RP,INTTrueAndCorrect#IdentifiersAustralianBusinessNumberIdentifier,INTTrueAndCorrect#PersonUnstructuredNameFullNameText,INTTrueAndCorrect#PersonNameDetailsPositionText,INTTrueAndCorrect#ElectronicContactTelephoneAreaCode,INTTrueAndCorrect#ElectronicContactTelephoneMinimalNumber,INTTrueAndCorrect#IdentifiersTaxAgentNumberIdentifier,INTTrueAndCorrect#DeclarationSignatureDate,INTTrueAndCorrect#DeclarationStatementAcceptedIndicator,INTTrueAndCorrect#DeclarationSignatoryIdentifierText,INTTrueAndCorrect";
    }
}
